@@ -1,6 +1,7 @@
 """Adapter implementations for various ticket systems."""
 
 from .aitrackdown import AITrackdownAdapter
+from .asana import AsanaAdapter
 from .github import GitHubAdapter
 from .hybrid import HybridAdapter
 from .jira import JiraAdapter
@@ -8,6 +9,7 @@ from .linear import LinearAdapter
 
 __all__ = [
     "AITrackdownAdapter",
+    "AsanaAdapter",
     "LinearAdapter",
     "JiraAdapter",
     "GitHubAdapter",
