@@ -1,5 +1,7 @@
 """AI-Trackdown adapter implementation."""
 
+from __future__ import annotations
+
 import builtins
 import json
 import logging
@@ -23,14 +25,14 @@ logger = logging.getLogger(__name__)
 
 # Import ai-trackdown-pytools when available
 try:
-    from ai_trackdown_pytools import AITrackdown
-    from ai_trackdown_pytools import Ticket as AITicket
+    from ai_trackdown_pytools import AITrackdown  # type: ignore[attr-defined]
+    from ai_trackdown_pytools import Ticket as AITicket  # type: ignore[attr-defined]
 
     HAS_AITRACKDOWN = True
 except ImportError:
     HAS_AITRACKDOWN = False
-    AITrackdown = None
-    AITicket = None
+    AITrackdown = None  # type: ignore[assignment]
+    AITicket = None  # type: ignore[assignment]
 
 
 class AITrackdownAdapter(BaseAdapter[Task]):
@@ -64,7 +66,7 @@ class AITrackdownAdapter(BaseAdapter[Task]):
 
         AITrackdown is file-based and doesn't require credentials.
 
-        Returns
+        Returns:
         -------
             (is_valid, error_message) - Always returns (True, "") for AITrackdown
 
@@ -130,6 +132,8 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             parent_issue=ai_ticket.get("parent_issue"),
             parent_epic=ai_ticket.get("parent_epic"),
             assignee=ai_ticket.get("assignee"),
+            estimated_hours=ai_ticket.get("estimated_hours"),
+            actual_hours=ai_ticket.get("actual_hours"),
             created_at=(
                 datetime.fromisoformat(ai_ticket["created_at"])
                 if "created_at" in ai_ticket
@@ -182,13 +186,15 @@ class AITrackdownAdapter(BaseAdapter[Task]):
         """Convert universal Task to AI-Trackdown ticket."""
         # Handle enum values that may be stored as strings due to use_enum_values=True
         # Note: task.state is always a string due to ConfigDict(use_enum_values=True)
-        state_value = task.state
+        state_value: str
         if isinstance(task.state, TicketState):
             state_value = self._get_state_mapping()[task.state]
         elif isinstance(task.state, str):
             # Already a string - keep as-is (don't convert to kebab-case)
             # The state is already in snake_case format from the enum value
             state_value = task.state
+        else:
+            state_value = str(task.state)
 
         return {
             "id": task.id,
@@ -210,13 +216,15 @@ class AITrackdownAdapter(BaseAdapter[Task]):
         """Convert universal Epic to AI-Trackdown ticket."""
         # Handle enum values that may be stored as strings due to use_enum_values=True
         # Note: epic.state is always a string due to ConfigDict(use_enum_values=True)
-        state_value = epic.state
+        state_value: str
         if isinstance(epic.state, TicketState):
             state_value = self._get_state_mapping()[epic.state]
         elif isinstance(epic.state, str):
             # Already a string - keep as-is (don't convert to kebab-case)
             # The state is already in snake_case format from the enum value
             state_value = epic.state
+        else:
+            state_value = str(epic.state)
 
         return {
             "id": epic.id,
@@ -1234,6 +1242,126 @@ class AITrackdownAdapter(BaseAdapter[Task]):
         ]
         return statuses
 
+    # Milestone Methods (Not yet implemented)
+
+    async def milestone_create(
+        self,
+        name: str,
+        target_date: datetime | None = None,
+        labels: list[str] | None = None,
+        description: str = "",
+        project_id: str | None = None,
+    ) -> Any:
+        """Create milestone - not yet implemented for AITrackdown.
+
+        Args:
+        ----
+            name: Milestone name
+            target_date: Target completion date
+            labels: Labels that define this milestone
+            description: Milestone description
+            project_id: Associated project ID
+
+        Raises:
+        ------
+            NotImplementedError: Milestone support coming in v2.1.0
+
+        """
+        raise NotImplementedError("Milestone support for AITrackdown coming in v2.1.0")
+
+    async def milestone_get(self, milestone_id: str) -> Any:
+        """Get milestone - not yet implemented for AITrackdown.
+
+        Args:
+        ----
+            milestone_id: Milestone identifier
+
+        Raises:
+        ------
+            NotImplementedError: Milestone support coming in v2.1.0
+
+        """
+        raise NotImplementedError("Milestone support for AITrackdown coming in v2.1.0")
+
+    async def milestone_list(
+        self,
+        project_id: str | None = None,
+        state: str | None = None,
+    ) -> list[Any]:
+        """List milestones - not yet implemented for AITrackdown.
+
+        Args:
+        ----
+            project_id: Filter by project
+            state: Filter by state
+
+        Raises:
+        ------
+            NotImplementedError: Milestone support coming in v2.1.0
+
+        """
+        raise NotImplementedError("Milestone support for AITrackdown coming in v2.1.0")
+
+    async def milestone_update(
+        self,
+        milestone_id: str,
+        name: str | None = None,
+        target_date: datetime | None = None,
+        state: str | None = None,
+        labels: list[str] | None = None,
+        description: str | None = None,
+    ) -> Any:
+        """Update milestone - not yet implemented for AITrackdown.
+
+        Args:
+        ----
+            milestone_id: Milestone identifier
+            name: New name
+            target_date: New target date
+            state: New state
+            labels: New labels
+            description: New description
+
+        Raises:
+        ------
+            NotImplementedError: Milestone support coming in v2.1.0
+
+        """
+        raise NotImplementedError("Milestone support for AITrackdown coming in v2.1.0")
+
+    async def milestone_delete(self, milestone_id: str) -> bool:
+        """Delete milestone - not yet implemented for AITrackdown.
+
+        Args:
+        ----
+            milestone_id: Milestone identifier
+
+        Raises:
+        ------
+            NotImplementedError: Milestone support coming in v2.1.0
+
+        """
+        raise NotImplementedError("Milestone support for AITrackdown coming in v2.1.0")
+
+    async def milestone_get_issues(
+        self,
+        milestone_id: str,
+        state: str | None = None,
+    ) -> list[Any]:
+        """Get milestone issues - not yet implemented for AITrackdown.
+
+        Args:
+        ----
+            milestone_id: Milestone identifier
+            state: Filter by issue state
+
+        Raises:
+        ------
+            NotImplementedError: Milestone support coming in v2.1.0
+
+        """
+        raise NotImplementedError("Milestone support for AITrackdown coming in v2.1.0")
+
 
 # Register the adapter
 AdapterRegistry.register("aitrackdown", AITrackdownAdapter)
