@@ -51,6 +51,34 @@ class LinearStateMapping:
         "canceled": TicketState.CLOSED,
     }
 
+    # Semantic state name mappings for flexible workflow matching (1M-552)
+    # Maps universal states to common Linear state names (case-insensitive)
+    SEMANTIC_NAMES: dict[TicketState, list[str]] = {
+        TicketState.OPEN: ["todo", "to do", "open", "new", "backlog"],
+        TicketState.READY: ["ready", "triage", "ready for dev", "ready to start"],
+        TicketState.TESTED: [
+            "tested",
+            "in review",
+            "review",
+            "qa",
+            "testing",
+            "ready for review",
+        ],
+        TicketState.WAITING: ["waiting", "on hold", "paused"],
+        TicketState.BLOCKED: ["blocked"],
+        TicketState.IN_PROGRESS: [
+            "in progress",
+            "in-progress",
+            "started",
+            "doing",
+            "active",
+            "in development",
+            "in dev",
+        ],
+        TicketState.DONE: ["done", "completed", "finished"],
+        TicketState.CLOSED: ["closed", "canceled", "cancelled", "won't do", "wont do"],
+    }
+
 
 class LinearWorkflowStateType(Enum):
     """Linear workflow state types."""
@@ -128,17 +156,99 @@ def get_linear_state_type(state: TicketState) -> str:
     return LinearStateMapping.TO_LINEAR.get(state, "unstarted")
 
 
-def get_universal_state(linear_state_type: str) -> TicketState:
-    """Convert Linear workflow state type to universal TicketState.
+def get_universal_state(
+    linear_state_type: str, state_name: str | None = None
+) -> TicketState:
+    """Convert Linear workflow state type to universal TicketState with synonym matching.
+
+    This function implements intelligent state mapping with fallback strategies:
+    1. Try exact match on state type (backlog, unstarted, started, completed, canceled)
+    2. Try synonym matching on state name (ToDo, In Review, Testing, etc.)
+    3. Default to OPEN for unknown states
+
+    Synonym Matching Rules (ticket 1M-164, fixed in v2.0.4):
+    - "done", "completed", "finished", "resolved" → DONE
+    - "closed", "canceled", "cancelled", "won't do" → CLOSED
+    - Everything else → OPEN
 
     Args:
-        linear_state_type: Linear workflow state type string
+        linear_state_type: Linear workflow state type string (from state.type field)
+        state_name: Linear workflow state name (from state.name field, optional)
 
     Returns:
         Universal ticket state enum
 
     """
-    return LinearStateMapping.FROM_LINEAR.get(linear_state_type, TicketState.OPEN)
+    # First try exact type match
+    if linear_state_type in LinearStateMapping.FROM_LINEAR:
+        return LinearStateMapping.FROM_LINEAR[linear_state_type]
+
+    # If no exact match and state_name provided, try synonym matching
+    if state_name:
+        state_name_lower = state_name.lower().strip()
+
+        # DONE states: Work successfully completed
+        # - User finished the work
+        # - Requirements met
+        # - Quality verified
+        done_synonyms = [
+            "done",
+            "completed",
+            "finished",
+            "resolved",
+        ]
+
+        if any(synonym in state_name_lower for synonym in done_synonyms):
+            return TicketState.DONE
+
+        # CLOSED states: Work terminated without completion
+        # - User decided not to do it
+        # - Requirements changed
+        # - Duplicate/invalid ticket
+        closed_synonyms = [
+            "closed",
+            "cancelled",
+            "canceled",
+            "won't do",
+            "wont do",
+            "rejected",
+        ]
+
+        if any(synonym in state_name_lower for synonym in closed_synonyms):
+            return TicketState.CLOSED
+
+        # Check for "in progress" synonyms
+        in_progress_synonyms = [
+            "in progress",
+            "in-progress",
+            "working",
+            "active",
+            "started",
+            "doing",
+            "in development",
+            "in dev",
+        ]
+
+        if any(synonym in state_name_lower for synonym in in_progress_synonyms):
+            return TicketState.IN_PROGRESS
+
+        # Check for "review/testing" synonyms
+        review_synonyms = [
+            "review",
+            "in review",
+            "in-review",
+            "testing",
+            "in test",
+            "in-test",
+            "qa",
+            "ready for review",
+        ]
+
+        if any(synonym in state_name_lower for synonym in review_synonyms):
+            return TicketState.READY
+
+    # Default: everything else is OPEN (including "ToDo", "Backlog", "To Do", etc.)
+    return TicketState.OPEN
 
 
 def build_issue_filter(
