@@ -12,6 +12,7 @@ import asyncio
 import json
 import os
 from pathlib import Path
+from typing import Any
 
 import typer
 from rich.console import Console
@@ -275,15 +276,44 @@ async def _validate_configuration_with_retry(
                         current_config["default_tags"] = default_values["default_tags"]
 
                 elif adapter_type == "jira":
-                    adapter_config = _configure_jira(interactive=True)
+                    # Returns tuple: (AdapterConfig, default_values_dict)
+                    adapter_config, default_values = _configure_jira(interactive=True)
                     current_config["adapters"]["jira"] = adapter_config.to_dict()
 
+                    # Merge default values into top-level config
+                    if default_values.get("default_user"):
+                        current_config["default_user"] = default_values["default_user"]
+                    if default_values.get("default_epic"):
+                        current_config["default_epic"] = default_values["default_epic"]
+                    if default_values.get("default_project"):
+                        current_config["default_project"] = default_values[
+                            "default_project"
+                        ]
+                    if default_values.get("default_tags"):
+                        current_config["default_tags"] = default_values["default_tags"]
+
                 elif adapter_type == "github":
-                    adapter_config = _configure_github(interactive=True)
+                    # Returns tuple: (AdapterConfig, default_values_dict)
+                    adapter_config, default_values = _configure_github(interactive=True)
                     current_config["adapters"]["github"] = adapter_config.to_dict()
 
+                    # Merge default values into top-level config
+                    if default_values.get("default_user"):
+                        current_config["default_user"] = default_values["default_user"]
+                    if default_values.get("default_epic"):
+                        current_config["default_epic"] = default_values["default_epic"]
+                    if default_values.get("default_project"):
+                        current_config["default_project"] = default_values[
+                            "default_project"
+                        ]
+                    if default_values.get("default_tags"):
+                        current_config["default_tags"] = default_values["default_tags"]
+
                 elif adapter_type == "aitrackdown":
-                    adapter_config = _configure_aitrackdown(interactive=True)
+                    # Returns tuple: (AdapterConfig, default_values_dict)
+                    adapter_config, default_values = _configure_aitrackdown(
+                        interactive=True
+                    )
                     current_config["adapters"]["aitrackdown"] = adapter_config.to_dict()
                     # Save updated configuration
                     with open(config_file_path, "w") as f:
@@ -391,9 +421,9 @@ def _init_adapter_internal(
     jira_server: str | None = None,
     jira_email: str | None = None,
     jira_project: str | None = None,
-    github_owner: str | None = None,
-    github_repo: str | None = None,
+    github_url: str | None = None,
     github_token: str | None = None,
+    **kwargs: Any,
 ) -> bool:
     """Internal function to initialize adapter configuration.
 
@@ -411,9 +441,9 @@ def _init_adapter_internal(
         jira_server: JIRA server URL
         jira_email: JIRA user email for authentication
         jira_project: Default JIRA project key
-        github_owner: GitHub repository owner
-        github_repo: GitHub repository name
+        github_url: GitHub repository URL (e.g., https://github.com/owner/repo)
         github_token: GitHub Personal Access Token
+        **kwargs: Additional parameters (includes deprecated github_owner, github_repo for backward compatibility)
 
     Returns:
     -------
@@ -560,7 +590,8 @@ def _init_adapter_internal(
                 )
 
                 # Use consolidated configure function (interactive if missing params)
-                adapter_config = _configure_jira(
+                # Returns tuple: (AdapterConfig, default_values_dict) - following Linear pattern
+                adapter_config, default_values = _configure_jira(
                     interactive=not has_all_params,
                     server=jira_server,
                     email=jira_email,
@@ -570,6 +601,16 @@ def _init_adapter_internal(
 
                 config["adapters"]["jira"] = adapter_config.to_dict()
 
+                # Merge default values into top-level config
+                if default_values.get("default_user"):
+                    config["default_user"] = default_values["default_user"]
+                if default_values.get("default_epic"):
+                    config["default_epic"] = default_values["default_epic"]
+                if default_values.get("default_project"):
+                    config["default_project"] = default_values["default_project"]
+                if default_values.get("default_tags"):
+                    config["default_tags"] = default_values["default_tags"]
+
             except ValueError as e:
                 console.print(f"[red]Error:[/red] {e}")
                 return False
@@ -578,16 +619,27 @@ def _init_adapter_internal(
         # If not auto-discovered, build from CLI params or use consolidated function
         if adapter_type not in config["adapters"]:
             try:
+                # Extract deprecated parameters for backward compatibility
+                github_owner = kwargs.get("github_owner")
+                github_repo = kwargs.get("github_repo")
+
                 # Determine if we need interactive prompts
+                # Prioritize github_url, fallback to owner/repo
                 has_all_params = bool(
-                    (github_owner or os.getenv("GITHUB_OWNER"))
-                    and (github_repo or os.getenv("GITHUB_REPO"))
+                    (
+                        github_url
+                        or os.getenv("GITHUB_REPO_URL")
+                        or (github_owner or os.getenv("GITHUB_OWNER"))
+                        and (github_repo or os.getenv("GITHUB_REPO"))
+                    )
                     and (github_token or os.getenv("GITHUB_TOKEN"))
                 )
 
                 # Use consolidated configure function (interactive if missing params)
-                adapter_config = _configure_github(
+                # Returns tuple: (AdapterConfig, default_values_dict) - following Linear pattern
+                adapter_config, default_values = _configure_github(
                     interactive=not has_all_params,
+                    repo_url=github_url,
                     owner=github_owner,
                     repo=github_repo,
                     token=github_token,
@@ -595,6 +647,16 @@ def _init_adapter_internal(
 
                 config["adapters"]["github"] = adapter_config.to_dict()
 
+                # Merge default values into top-level config
+                if default_values.get("default_user"):
+                    config["default_user"] = default_values["default_user"]
+                if default_values.get("default_epic"):
+                    config["default_epic"] = default_values["default_epic"]
+                if default_values.get("default_project"):
+                    config["default_project"] = default_values["default_project"]
+                if default_values.get("default_tags"):
+                    config["default_tags"] = default_values["default_tags"]
+
             except ValueError as e:
                 console.print(f"[red]Error:[/red] {e}")
                 return False
@@ -682,15 +744,17 @@ def init(
     jira_project: str | None = typer.Option(
         None, "--jira-project", help="Default JIRA project key"
     ),
-    github_owner: str | None = typer.Option(
-        None, "--github-owner", help="GitHub repository owner"
-    ),
-    github_repo: str | None = typer.Option(
-        None, "--github-repo", help="GitHub repository name"
+    github_url: str | None = typer.Option(
+        None,
+        "--github-url",
+        help="GitHub repository URL (e.g., https://github.com/owner/repo)",
     ),
     github_token: str | None = typer.Option(
         None, "--github-token", help="GitHub Personal Access Token"
     ),
+    # Deprecated parameters for backward compatibility (hidden from help)
+    github_owner: str | None = typer.Option(None, "--github-owner", hidden=True),
+    github_repo: str | None = typer.Option(None, "--github-repo", hidden=True),
 ) -> None:
     """Initialize adapter configuration only (without platform installation).
 
@@ -710,7 +774,7 @@ def init(
     - You get up to 3 retry attempts to fix configuration issues
     - You can always re-validate later with 'mcp-ticketer doctor'
 
-    Examples
+    Examples:
     --------
         # For first-time setup, use 'setup' instead (recommended)
         mcp-ticketer setup
@@ -805,9 +869,11 @@ def init(
         jira_server=jira_server,
         jira_email=jira_email,
         jira_project=jira_project,
+        github_url=github_url,
+        github_token=github_token,
+        # Pass deprecated parameters via kwargs for backward compatibility
         github_owner=github_owner,
         github_repo=github_repo,
-        github_token=github_token,
     )
 
     if not success:
