@@ -1,7 +1,7 @@
 """Linear-specific CLI commands for workspace and team management."""
 
 import os
-from typing import Optional
+import re
 
 import typer
 from gql import Client, gql
@@ -13,13 +13,96 @@ app = typer.Typer(name="linear", help="Linear workspace and team management")
 console = Console()
 
 
+async def derive_team_from_url(
+    api_key: str, team_url: str
+) -> tuple[str | None, str | None]:
+    """Derive team ID from Linear team issues URL.
+
+    Accepts URLs like:
+    - https://linear.app/1m-hyperdev/team/1M/active
+    - https://linear.app/1m-hyperdev/team/1M/
+    - https://linear.app/1m-hyperdev/team/1M
+
+    Args:
+        api_key: Linear API key
+        team_url: URL to Linear team issues page
+
+    Returns:
+        Tuple of (team_id, error_message). If successful, team_id is set and error_message is None.
+        If failed, team_id is None and error_message contains the error.
+
+    """
+    # Extract team key from URL using regex
+    # Pattern: https://linear.app/<workspace>/team/<TEAM_KEY>/...
+    pattern = r"https://linear\.app/[\w-]+/team/([\w-]+)"
+    match = re.search(pattern, team_url)
+
+    if not match:
+        return (
+            None,
+            "Invalid Linear team URL format. Expected: https://linear.app/<workspace>/team/<TEAM_KEY>",
+        )
+
+    team_key = match.group(1)
+    console.print(f"[dim]Extracted team key: {team_key}[/dim]")
+
+    # Query Linear API to resolve team key to team ID
+    query = gql(
+        """
+        query GetTeamByKey($key: String!) {
+            teams(filter: { key: { eq: $key } }) {
+                nodes {
+                    id
+                    key
+                    name
+                    organization {
+                        name
+                        urlKey
+                    }
+                }
+            }
+        }
+    """
+    )
+
+    try:
+        # Create client
+        transport = HTTPXTransport(
+            url="https://api.linear.app/graphql", headers={"Authorization": api_key}
+        )
+        client = Client(transport=transport, fetch_schema_from_transport=False)
+
+        # Execute query
+        result = client.execute(query, variable_values={"key": team_key})
+        teams = result.get("teams", {}).get("nodes", [])
+
+        if not teams:
+            return (
+                None,
+                f"Team with key '{team_key}' not found. Please check your team URL and API key.",
+            )
+
+        team = teams[0]
+        team_id = team["id"]
+        team_name = team["name"]
+
+        console.print(
+            f"[green]✓[/green] Resolved team: {team_name} (Key: {team_key}, ID: {team_id})"
+        )
+
+        return team_id, None
+
+    except Exception as e:
+        return None, f"Failed to query Linear API: {str(e)}"
+
+
 def _create_linear_client() -> Client:
     """Create a Linear GraphQL client."""
     api_key = os.getenv("LINEAR_API_KEY")
     if not api_key:
         console.print("[red]❌ LINEAR_API_KEY not found in environment[/red]")
         console.print("Set it in .env.local or environment variables")
-        raise typer.Exit(1)
+        raise typer.Exit(1) from None
 
     transport = HTTPXTransport(
         url="https://api.linear.app/graphql", headers={"Authorization": api_key}
@@ -28,7 +111,7 @@ def _create_linear_client() -> Client:
 
 
 @app.command("workspaces")
-def list_workspaces():
+def list_workspaces() -> None:
     """List all accessible Linear workspaces."""
     console.print("🔍 Discovering Linear workspaces...")
 
@@ -75,18 +158,18 @@ def list_workspaces():
 
     except Exception as e:
         console.print(f"[red]❌ Error fetching workspace info: {e}[/red]")
-        raise typer.Exit(1)
+        raise typer.Exit(1) from e
 
 
 @app.command("teams")
 def list_teams(
-    workspace: Optional[str] = typer.Option(
+    workspace: str | None = typer.Option(
         None, "--workspace", "-w", help="Workspace URL key (optional)"
     ),
     all_teams: bool = typer.Option(
         False, "--all", "-a", help="Show all teams across all workspaces"
     ),
-):
+) -> None:
     """List all teams in the current workspace or all accessible teams."""
     if all_teams:
         console.print("🔍 Discovering ALL accessible Linear teams across workspaces...")
@@ -245,25 +328,25 @@ def list_teams(
 
     except Exception as e:
         console.print(f"[red]❌ Error fetching teams: {e}[/red]")
-        raise typer.Exit(1)
+        raise typer.Exit(1) from e
 
 
 @app.command("configure")
 def configure_team(
-    team_key: Optional[str] = typer.Option(
+    team_key: str | None = typer.Option(
         None, "--team-key", "-k", help="Team key (e.g., '1M')"
     ),
-    team_id: Optional[str] = typer.Option(None, "--team-id", "-i", help="Team UUID"),
-    workspace: Optional[str] = typer.Option(
+    team_id: str | None = typer.Option(None, "--team-id", "-i", help="Team UUID"),
+    workspace: str | None = typer.Option(
         None, "--workspace", "-w", help="Workspace URL key"
     ),
-):
+) -> None:
     """Configure Linear adapter with a specific team."""
     from ..cli.main import load_config, save_config
 
     if not team_key and not team_id:
         console.print("[red]❌ Either --team-key or --team-id is required[/red]")
-        raise typer.Exit(1)
+        raise typer.Exit(1) from None
 
     console.print("🔧 Configuring Linear adapter...")
 
@@ -293,11 +376,11 @@ def configure_team(
 
             if not team:
                 console.print(f"[red]❌ Team with ID '{team_id}' not found[/red]")
-                raise typer.Exit(1)
+                raise typer.Exit(1) from None
 
         except Exception as e:
             console.print(f"[red]❌ Error validating team: {e}[/red]")
-            raise typer.Exit(1)
+            raise typer.Exit(1) from e
 
     elif team_key:
         # Validate team by key
@@ -326,14 +409,14 @@ def configure_team(
 
             if not teams:
                 console.print(f"[red]❌ Team with key '{team_key}' not found[/red]")
-                raise typer.Exit(1)
+                raise typer.Exit(1) from None
 
             team = teams[0]
             team_id = team["id"]  # Use the found team ID
 
         except Exception as e:
             console.print(f"[red]❌ Error validating team: {e}[/red]")
-            raise typer.Exit(1)
+            raise typer.Exit(1) from e
 
     # Update configuration
     config = load_config()
@@ -382,17 +465,17 @@ def configure_team(
 
 @app.command("info")
 def show_info(
-    team_key: Optional[str] = typer.Option(
+    team_key: str | None = typer.Option(
         None, "--team-key", "-k", help="Team key to show info for"
     ),
-    team_id: Optional[str] = typer.Option(
+    team_id: str | None = typer.Option(
         None, "--team-id", "-i", help="Team UUID to show info for"
     ),
-):
+) -> None:
     """Show detailed information about a specific team."""
     if not team_key and not team_id:
         console.print("[red]❌ Either --team-key or --team-id is required[/red]")
-        raise typer.Exit(1)
+        raise typer.Exit(1) from None
 
     # Query for detailed team information
     if team_id:
@@ -483,7 +566,7 @@ def show_info(
         if not team:
             identifier = team_id or team_key
             console.print(f"[red]❌ Team '{identifier}' not found[/red]")
-            raise typer.Exit(1)
+            raise typer.Exit(1) from None
 
         # Display team information
         console.print(f"\n🏷️  Team: {team.get('name')}")
@@ -530,4 +613,4 @@ def show_info(
 
     except Exception as e:
         console.print(f"[red]❌ Error fetching team info: {e}[/red]")
-        raise typer.Exit(1)
+        raise typer.Exit(1) from e
