@@ -20,11 +20,17 @@ from .configure import configure_wizard, set_adapter_config, show_current_config
 from .diagnostics import run_diagnostics
 from .discover import app as discover_app
 from .init_command import init
+from .install_mcp_server import (
+    install_mcp_server,
+    list_mcp_servers,
+    uninstall_mcp_server,
+)
 from .instruction_commands import app as instruction_app
 from .mcp_server_commands import mcp_app
 from .migrate_config import migrate_config_command
 from .platform_commands import app as platform_app
 from .platform_installer import install, remove, uninstall
+from .project_update_commands import app as project_update_app
 from .queue_commands import app as queue_app
 from .setup_command import setup
 from .ticket_commands import app as ticket_app
@@ -151,7 +157,7 @@ def load_config(project_dir: Path | None = None) -> dict:
 def _discover_from_env_files() -> str | None:
     """Discover adapter configuration from .env or .env.local files.
 
-    Returns
+    Returns:
     -------
         Adapter name if discovered, None otherwise
 
@@ -519,6 +525,9 @@ app.add_typer(discover_app, name="discover")
 # Add instructions command to main app
 app.add_typer(instruction_app, name="instructions")
 
+# Add project-update command group to main app
+app.add_typer(project_update_app, name="project-update")
+
 # Add setup and init commands to main app
 app.command()(setup)
 app.command()(init)
@@ -528,6 +537,11 @@ app.command()(install)
 app.command()(remove)
 app.command()(uninstall)
 
+# Add MCP server installer commands
+app.command(name="install-mcp-server")(install_mcp_server)
+app.command(name="list-mcp-servers")(list_mcp_servers)
+app.command(name="uninstall-mcp-server")(uninstall_mcp_server)
+
 
 # Add diagnostics command
 @app.command("doctor")
