@@ -321,8 +321,7 @@ def setup(
             jira_server=None,
             jira_email=None,
             jira_project=None,
-            github_owner=None,
-            github_repo=None,
+            github_url=None,
             github_token=None,
         )
 
@@ -353,7 +352,7 @@ def setup(
 
     # Detect available platforms
     detector = PlatformDetector()
-    detected = detector.detect_all(project_path=proj_path)
+    detected = detector.detect_all(project_path=proj_path, exclude_desktop=True)
 
     if not detected:
         console.print("[yellow]No AI platforms detected on this system.[/yellow]")
