@@ -4,9 +4,22 @@ from __future__ import annotations
 
 import builtins
 from abc import ABC, abstractmethod
+from datetime import datetime
 from typing import TYPE_CHECKING, Any, Generic, TypeVar
 
-from .models import Comment, Epic, SearchQuery, Task, TicketState, TicketType
+from .models import (
+    Comment,
+    Epic,
+    Milestone,
+    Project,
+    ProjectScope,
+    ProjectState,
+    ProjectStatistics,
+    SearchQuery,
+    Task,
+    TicketState,
+    TicketType,
+)
 from .state_matcher import get_state_matcher
 
 if TYPE_CHECKING:
@@ -37,7 +50,7 @@ class BaseAdapter(ABC, Generic[T]):
         This identifier is used in MCP responses to show which adapter
         handled the operation (e.g., "linear", "github", "jira", "asana").
 
-        Returns
+        Returns:
         -------
             Lowercase adapter type (e.g., "linear", "github")
 
@@ -56,7 +69,7 @@ class BaseAdapter(ABC, Generic[T]):
     def adapter_display_name(self) -> str:
         """Return human-readable adapter name.
 
-        Returns
+        Returns:
         -------
             Title-cased adapter name (e.g., "Linear", "Github", "Jira")
 
@@ -67,7 +80,7 @@ class BaseAdapter(ABC, Generic[T]):
     def _get_state_mapping(self) -> dict[TicketState, str]:
         """Get mapping from universal states to system-specific states.
 
-        Returns
+        Returns:
         -------
             Dictionary mapping TicketState to system-specific state strings
 
@@ -78,7 +91,7 @@ class BaseAdapter(ABC, Generic[T]):
     def validate_credentials(self) -> tuple[bool, str]:
         """Validate that required credentials are present.
 
-        Returns
+        Returns:
         -------
             (is_valid, error_message) - Tuple of validation result and error message
 
@@ -346,7 +359,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         # Check parent/child state constraint
         # If this ticket has children, ensure target state >= max child state
-        if isinstance(ticket, Task) and ticket.children:
+        if isinstance(ticket, Task):
             # Get all children
             children = await self.list_tasks_by_issue(ticket_id)
             if children:
@@ -612,3 +625,356 @@ class BaseAdapter(ABC, Generic[T]):
     async def close(self) -> None:
         """Close adapter and cleanup resources."""
         pass
+
+    # Milestone Operations (Phase 1 - Abstract methods)
+
+    @abstractmethod
+    async def milestone_create(
+        self,
+        name: str,
+        target_date: datetime | None = None,
+        labels: list[str] | None = None,
+        description: str = "",
+        project_id: str | None = None,
+    ) -> Milestone:
+        """Create a new milestone.
+
+        Args:
+        ----
+            name: Milestone name
+            target_date: Target completion date (ISO format: YYYY-MM-DD)
+            labels: Labels that define this milestone
+            description: Milestone description
+            project_id: Associated project ID
+
+        Returns:
+        -------
+            Created Milestone object
+
+        """
+        pass
+
+    @abstractmethod
+    async def milestone_get(self, milestone_id: str) -> Milestone | None:
+        """Get milestone by ID with progress calculation.
+
+        Args:
+        ----
+            milestone_id: Milestone identifier
+
+        Returns:
+        -------
+            Milestone object with calculated progress, None if not found
+
+        """
+        pass
+
+    @abstractmethod
+    async def milestone_list(
+        self,
+        project_id: str | None = None,
+        state: str | None = None,
+    ) -> builtins.list[Milestone]:
+        """List milestones with optional filters.
+
+        Args:
+        ----
+            project_id: Filter by project
+            state: Filter by state (open, active, completed, closed)
+
+        Returns:
+        -------
+            List of Milestone objects
+
+        """
+        pass
+
+    @abstractmethod
+    async def milestone_update(
+        self,
+        milestone_id: str,
+        name: str | None = None,
+        target_date: datetime | None = None,
+        state: str | None = None,
+        labels: list[str] | None = None,
+        description: str | None = None,
+    ) -> Milestone | None:
+        """Update milestone properties.
+
+        Args:
+        ----
+            milestone_id: Milestone identifier
+            name: New name (optional)
+            target_date: New target date (optional)
+            state: New state (optional)
+            labels: New labels (optional)
+            description: New description (optional)
+
+        Returns:
+        -------
+            Updated Milestone object, None if not found
+
+        """
+        pass
+
+    @abstractmethod
+    async def milestone_delete(self, milestone_id: str) -> bool:
+        """Delete milestone.
+
+        Args:
+        ----
+            milestone_id: Milestone identifier
+
+        Returns:
+        -------
+            True if deleted successfully, False otherwise
+
+        """
+        pass
+
+    @abstractmethod
+    async def milestone_get_issues(
+        self,
+        milestone_id: str,
+        state: str | None = None,
+    ) -> builtins.list[Task]:
+        """Get issues associated with milestone.
+
+        Args:
+        ----
+            milestone_id: Milestone identifier
+            state: Filter by issue state (optional)
+
+        Returns:
+        -------
+            List of Task objects (issues)
+
+        """
+        pass
+
+    # Project Operations (Phase 1 - Abstract methods)
+    # These methods are optional - adapters that don't support projects
+    # can raise NotImplementedError with a helpful message
+
+    async def project_list(
+        self,
+        scope: ProjectScope | None = None,
+        state: ProjectState | None = None,
+        limit: int = 50,
+        offset: int = 0,
+    ) -> builtins.list[Project]:
+        """List projects with optional filters.
+
+        Args:
+        ----
+            scope: Filter by project scope (user, team, org, repo)
+            state: Filter by project state
+            limit: Maximum results (default: 50)
+            offset: Pagination offset (default: 0)
+
+        Returns:
+        -------
+            List of Project objects
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project operations. "
+            "Use Epic operations for this adapter."
+        )
+
+    async def project_get(self, project_id: str) -> Project | None:
+        """Get project by ID.
+
+        Args:
+        ----
+            project_id: Project identifier (platform-specific or unified)
+
+        Returns:
+        -------
+            Project object if found, None otherwise
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project operations. "
+            "Use get_epic() for this adapter."
+        )
+
+    async def project_create(
+        self,
+        name: str,
+        description: str | None = None,
+        state: ProjectState = ProjectState.PLANNED,
+        target_date: datetime | None = None,
+        **kwargs: Any,
+    ) -> Project:
+        """Create new project.
+
+        Args:
+        ----
+            name: Project name (required)
+            description: Project description
+            state: Initial project state (default: PLANNED)
+            target_date: Target completion date
+            **kwargs: Platform-specific additional fields
+
+        Returns:
+        -------
+            Created Project object
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project operations. "
+            "Use create_epic() for this adapter."
+        )
+
+    async def project_update(
+        self,
+        project_id: str,
+        name: str | None = None,
+        description: str | None = None,
+        state: ProjectState | None = None,
+        **kwargs: Any,
+    ) -> Project | None:
+        """Update project properties.
+
+        Args:
+        ----
+            project_id: Project identifier
+            name: New name (optional)
+            description: New description (optional)
+            state: New state (optional)
+            **kwargs: Platform-specific fields to update
+
+        Returns:
+        -------
+            Updated Project object, None if not found
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project operations."
+        )
+
+    async def project_delete(self, project_id: str) -> bool:
+        """Delete or archive project.
+
+        Args:
+        ----
+            project_id: Project identifier
+
+        Returns:
+        -------
+            True if deleted successfully, False otherwise
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project operations."
+        )
+
+    async def project_get_issues(
+        self, project_id: str, state: TicketState | None = None
+    ) -> builtins.list[Task]:
+        """Get all issues in project.
+
+        Args:
+        ----
+            project_id: Project identifier
+            state: Filter by issue state (optional)
+
+        Returns:
+        -------
+            List of Task objects (issues in project)
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project operations. "
+            "Use list_issues_by_epic() for this adapter."
+        )
+
+    async def project_add_issue(self, project_id: str, issue_id: str) -> bool:
+        """Add issue to project.
+
+        Args:
+        ----
+            project_id: Project identifier
+            issue_id: Issue identifier to add
+
+        Returns:
+        -------
+            True if added successfully, False otherwise
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project operations."
+        )
+
+    async def project_remove_issue(self, project_id: str, issue_id: str) -> bool:
+        """Remove issue from project.
+
+        Args:
+        ----
+            project_id: Project identifier
+            issue_id: Issue identifier to remove
+
+        Returns:
+        -------
+            True if removed successfully, False otherwise
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project operations."
+        )
+
+    async def project_get_statistics(self, project_id: str) -> ProjectStatistics:
+        """Get project statistics and metrics.
+
+        Calculates or retrieves statistics including issue counts by state,
+        progress percentage, and velocity metrics.
+
+        Args:
+        ----
+            project_id: Project identifier
+
+        Returns:
+        -------
+            ProjectStatistics object with calculated metrics
+
+        Raises:
+        ------
+            NotImplementedError: If adapter doesn't support projects
+
+        """
+        raise NotImplementedError(
+            f"{self.__class__.__name__} does not support project statistics."
+        )
