@@ -6,7 +6,7 @@ import os
 from enum import Enum
 from functools import lru_cache
 from pathlib import Path
-from typing import Any, Optional
+from typing import Any, Optional, cast
 
 import yaml
 from pydantic import BaseModel, Field, field_validator, model_validator
@@ -38,9 +38,9 @@ class GitHubConfig(BaseAdapterConfig):
     """GitHub adapter configuration."""
 
     type: AdapterType = AdapterType.GITHUB
-    token: str | None = Field(None, env="GITHUB_TOKEN")
-    owner: str | None = Field(None, env="GITHUB_OWNER")
-    repo: str | None = Field(None, env="GITHUB_REPO")
+    token: str | None = Field(default=None)
+    owner: str | None = Field(default=None)
+    repo: str | None = Field(default=None)
     api_url: str = "https://api.github.com"
     use_projects_v2: bool = False
     custom_priority_scheme: dict[str, list[str]] | None = None
@@ -53,7 +53,7 @@ class GitHubConfig(BaseAdapterConfig):
             v = os.getenv("GITHUB_TOKEN")
         if not v:
             raise ValueError("GitHub token is required")
-        return v
+        return cast(str, v)
 
     @field_validator("owner", mode="before")
     @classmethod
@@ -63,7 +63,7 @@ class GitHubConfig(BaseAdapterConfig):
             v = os.getenv("GITHUB_OWNER")
         if not v:
             raise ValueError("GitHub owner is required")
-        return v
+        return cast(str, v)
 
     @field_validator("repo", mode="before")
     @classmethod
@@ -73,17 +73,17 @@ class GitHubConfig(BaseAdapterConfig):
             v = os.getenv("GITHUB_REPO")
         if not v:
             raise ValueError("GitHub repo is required")
-        return v
+        return cast(str, v)
 
 
 class JiraConfig(BaseAdapterConfig):
     """JIRA adapter configuration."""
 
     type: AdapterType = AdapterType.JIRA
-    server: str | None = Field(None, env="JIRA_SERVER")
-    email: str | None = Field(None, env="JIRA_EMAIL")
-    api_token: str | None = Field(None, env="JIRA_API_TOKEN")
-    project_key: str | None = Field(None, env="JIRA_PROJECT_KEY")
+    server: str | None = Field(default=None)
+    email: str | None = Field(default=None)
+    api_token: str | None = Field(default=None)
+    project_key: str | None = Field(default=None)
     cloud: bool = True
     verify_ssl: bool = True
 
@@ -95,7 +95,7 @@ class JiraConfig(BaseAdapterConfig):
             v = os.getenv("JIRA_SERVER")
         if not v:
             raise ValueError("JIRA server URL is required")
-        return v.rstrip("/")
+        return cast(str, v).rstrip("/")
 
     @field_validator("email", mode="before")
     @classmethod
@@ -105,7 +105,7 @@ class JiraConfig(BaseAdapterConfig):
             v = os.getenv("JIRA_EMAIL")
         if not v:
             raise ValueError("JIRA email is required")
-        return v
+        return cast(str, v)
 
     @field_validator("api_token", mode="before")
     @classmethod
@@ -115,14 +115,14 @@ class JiraConfig(BaseAdapterConfig):
             v = os.getenv("JIRA_API_TOKEN")
         if not v:
             raise ValueError("JIRA API token is required")
-        return v
+        return cast(str, v)
 
 
 class LinearConfig(BaseAdapterConfig):
     """Linear adapter configuration."""
 
     type: AdapterType = AdapterType.LINEAR
-    api_key: str | None = Field(None, env="LINEAR_API_KEY")
+    api_key: str | None = Field(default=None)
     workspace: str | None = None
     team_key: str | None = None  # Short team key like "BTA"
     team_id: str | None = None  # UUID team identifier
@@ -143,7 +143,7 @@ class LinearConfig(BaseAdapterConfig):
             v = os.getenv("LINEAR_API_KEY")
         if not v:
             raise ValueError("Linear API key is required")
-        return v
+        return cast(str, v)
 
 
 class AITrackdownConfig(BaseAdapterConfig):
@@ -343,16 +343,16 @@ class ConfigurationManager:
         try:
             with open(config_path, encoding="utf-8") as file:
                 if config_path.suffix.lower() in [".yaml", ".yml"]:
-                    return yaml.safe_load(file) or {}
+                    return cast(dict[str, Any], yaml.safe_load(file) or {})
                 elif config_path.suffix.lower() == ".json":
-                    return json.load(file)
+                    return cast(dict[str, Any], json.load(file))
                 else:
                     # Try YAML first, then JSON
                     content = file.read()
                     try:
-                        return yaml.safe_load(content) or {}
+                        return cast(dict[str, Any], yaml.safe_load(content) or {})
                     except yaml.YAMLError:
-                        return json.loads(content)
+                        return cast(dict[str, Any], json.loads(content))
         except Exception as e:
             logger.error(f"Error loading config file {config_path}: {e}")
             return {}
@@ -382,7 +382,7 @@ class ConfigurationManager:
                 }
 
             # Convert discovered adapters to config format
-            config_data = {"adapters": {}, "default_adapter": None}
+            config_data: dict[str, Any] = {"adapters": {}, "default_adapter": None}
 
             for adapter in discovered.adapters:
                 adapter_config = {"type": adapter.adapter_type, "enabled": True}
