@@ -186,6 +186,12 @@ class TicketerConfig:
     default_project: str | None = None  # Default project/epic ID (supports URLs)
     default_epic: str | None = None  # Alias for default_project (backward compat)
     default_tags: list[str] | None = None  # Default tags for new tickets
+    default_team: str | None = None  # Default team ID/key for multi-team platforms
+    default_cycle: str | None = None  # Default sprint/cycle ID for timeline scoping
+    assignment_labels: list[str] | None = None  # Labels indicating ticket assignment
+
+    # Automatic project updates configuration (1M-315)
+    auto_project_updates: dict[str, Any] | None = None  # Auto update settings
 
     def __post_init__(self):
         """Normalize default_project if it's a URL."""
@@ -249,6 +255,14 @@ class TicketerConfig:
             result["default_epic"] = self.default_epic
         if self.default_tags is not None:
             result["default_tags"] = self.default_tags
+        if self.default_team is not None:
+            result["default_team"] = self.default_team
+        if self.default_cycle is not None:
+            result["default_cycle"] = self.default_cycle
+        if self.assignment_labels is not None:
+            result["assignment_labels"] = self.assignment_labels
+        if self.auto_project_updates is not None:
+            result["auto_project_updates"] = self.auto_project_updates
         return result
 
     @classmethod
@@ -280,6 +294,10 @@ class TicketerConfig:
             default_project=data.get("default_project"),
             default_epic=data.get("default_epic"),
             default_tags=data.get("default_tags"),
+            default_team=data.get("default_team"),
+            default_cycle=data.get("default_cycle"),
+            assignment_labels=data.get("assignment_labels"),
+            auto_project_updates=data.get("auto_project_updates"),
         )
 
 
