@@ -13,17 +13,15 @@ from ....core.instructions import (
     InstructionsValidationError,
     TicketInstructionsManager,
 )
-from ..server_sdk import mcp
 
 
-@mcp.tool()
 async def instructions_get() -> dict[str, Any]:
     """Get current ticket writing instructions.
 
     Retrieves the active instructions for the current project, which may be
     custom project-specific instructions or the default embedded instructions.
 
-    Returns
+    Returns:
     -------
         A dictionary containing:
         - status: "completed" or "error"
@@ -76,7 +74,6 @@ async def instructions_get() -> dict[str, Any]:
         }
 
 
-@mcp.tool()
 async def instructions_set(content: str, source: str = "inline") -> dict[str, Any]:
     r"""Set custom ticket writing instructions for the project.
 
@@ -147,14 +144,13 @@ async def instructions_set(content: str, source: str = "inline") -> dict[str, An
         }
 
 
-@mcp.tool()
 async def instructions_reset() -> dict[str, Any]:
     """Reset to default instructions by deleting custom instructions.
 
     Removes any custom project-specific instructions, causing the system
     to revert to using the default embedded instructions.
 
-    Returns
+    Returns:
     -------
         A dictionary containing:
         - status: "completed" or "error"
@@ -211,7 +207,6 @@ async def instructions_reset() -> dict[str, Any]:
         }
 
 
-@mcp.tool()
 async def instructions_validate(content: str) -> dict[str, Any]:
     """Validate ticket instructions content without saving.
 
