@@ -4,11 +4,14 @@ This module provides MCP tools for label normalization, deduplication, merging,
 and cleanup operations across ticket systems.
 
 Features:
-- List labels from adapters with usage statistics
-- Normalize label names with configurable casing
-- Find duplicate labels with similarity scoring
-- Merge and rename labels across tickets
-- Generate comprehensive cleanup reports
+- label: Unified interface for all label operations (list, normalize, merge, etc.)
+- label_list: List labels from adapters (deprecated, use label(action="list"))
+- label_normalize: Normalize label names (deprecated, use label(action="normalize"))
+- label_find_duplicates: Find duplicate labels (deprecated, use label(action="find_duplicates"))
+- label_suggest_merge: Preview merge operation (deprecated, use label(action="suggest_merge"))
+- label_merge: Merge labels (deprecated, use label(action="merge"))
+- label_rename: Rename labels (deprecated, use label(action="rename"))
+- label_cleanup_report: Generate cleanup report (deprecated, use label(action="cleanup_report"))
 
 All tools follow the MCP response pattern:
     {
@@ -21,10 +24,12 @@ All tools follow the MCP response pattern:
 """
 
 import logging
+import warnings
 from typing import Any
 
 from ....core.label_manager import CasingStrategy, LabelDeduplicator, LabelNormalizer
 from ....core.models import SearchQuery
+from ....utils.token_utils import estimate_json_tokens
 from ..server_sdk import get_adapter, get_router, has_router, mcp
 
 logger = logging.getLogger(__name__)
@@ -49,55 +54,226 @@ def _build_adapter_metadata(adapter: Any) -> dict[str, Any]:
 
 
 @mcp.tool()
+async def label(
+    action: str,
+    adapter_name: str | None = None,
+    include_usage_count: bool = False,
+    limit: int = 100,
+    offset: int = 0,
+    label_name: str | None = None,
+    casing: str = "lowercase",
+    threshold: float = 0.85,
+    source_label: str | None = None,
+    target_label: str | None = None,
+    update_tickets: bool = True,
+    dry_run: bool = False,
+    old_name: str | None = None,
+    new_name: str | None = None,
+    include_spelling: bool = True,
+    include_duplicates: bool = True,
+    include_unused: bool = True,
+) -> dict[str, Any]:
+    """Unified label management tool with action-based routing.
+
+    This tool consolidates all label operations into a single interface:
+    - list: List all available labels
+    - normalize: Normalize label name with casing strategy
+    - find_duplicates: Find duplicate/similar labels
+    - suggest_merge: Preview label merge operation
+    - merge: Merge source label into target
+    - rename: Rename label (alias for merge)
+    - cleanup_report: Generate comprehensive cleanup report
+
+    Args:
+        action: Operation to perform. Valid values:
+            - "list": List labels from adapter
+            - "normalize": Normalize label name
+            - "find_duplicates": Find duplicate/similar labels
+            - "suggest_merge": Preview merge operation
+            - "merge": Merge labels across tickets
+            - "rename": Rename label (semantic alias for merge)
+            - "cleanup_report": Generate cleanup report
+
+        # Parameters for "list" action
+        adapter_name: Optional adapter name (for multi-adapter setups)
+        include_usage_count: Include usage statistics (default: False)
+        limit: Maximum results (default: 100, max: 500)
+        offset: Pagination offset (default: 0)
+
+        # Parameters for "normalize" action
+        label_name: Label name to normalize (required for normalize)
+        casing: Casing strategy - lowercase, titlecase, uppercase, kebab-case, snake_case (default: "lowercase")
+
+        # Parameters for "find_duplicates" action
+        threshold: Similarity threshold 0.0-1.0 (default: 0.85)
+        # limit also used here (default: 50)
+
+        # Parameters for "suggest_merge" action
+        source_label: Source label to merge from (required for suggest_merge, merge)
+        target_label: Target label to merge into (required for suggest_merge, merge)
+
+        # Parameters for "merge" action
+        # source_label, target_label (required)
+        update_tickets: Actually update tickets (default: True)
+        dry_run: Preview changes without applying (default: False)
+
+        # Parameters for "rename" action
+        old_name: Current label name (required for rename)
+        new_name: New label name (required for rename)
+        # update_tickets also used here
+
+        # Parameters for "cleanup_report" action
+        include_spelling: Include spelling analysis (default: True)
+        include_duplicates: Include duplicate analysis (default: True)
+        include_unused: Include unused label analysis (default: True)
+
+    Returns:
+        Results specific to action with status and relevant data
+
+    Examples:
+        # List labels
+        label(action="list", limit=50)
+
+        # Normalize label
+        label(action="normalize", label_name="Bug Report", casing="kebab-case")
+
+        # Find duplicates
+        label(action="find_duplicates", threshold=0.9, limit=20)
+
+        # Preview merge
+        label(action="suggest_merge", source_label="bug", target_label="bugfix")
+
+        # Merge labels
+        label(action="merge", source_label="bug", target_label="bugfix")
+
+        # Rename label
+        label(action="rename", old_name="feture", new_name="feature")
+
+        # Generate cleanup report
+        label(action="cleanup_report", include_spelling=True)
+
+    Migration from old tools:
+        - label_list(...) → label(action="list", ...)
+        - label_normalize(...) → label(action="normalize", ...)
+        - label_find_duplicates(...) → label(action="find_duplicates", ...)
+        - label_suggest_merge(...) → label(action="suggest_merge", ...)
+        - label_merge(...) → label(action="merge", ...)
+        - label_rename(...) → label(action="rename", ...)
+        - label_cleanup_report(...) → label(action="cleanup_report", ...)
+
+    See: docs/mcp-api-reference.md for detailed response formats
+    """
+    action_lower = action.lower()
+
+    # Route to appropriate handler based on action
+    if action_lower == "list":
+        return await label_list(
+            adapter_name=adapter_name,
+            include_usage_count=include_usage_count,
+            limit=limit,
+            offset=offset,
+        )
+    elif action_lower == "normalize":
+        if label_name is None:
+            return {
+                "status": "error",
+                "error": "label_name is required for normalize action",
+            }
+        return await label_normalize(label_name=label_name, casing=casing)
+    elif action_lower == "find_duplicates":
+        return await label_find_duplicates(threshold=threshold, limit=limit)
+    elif action_lower == "suggest_merge":
+        if source_label is None or target_label is None:
+            return {
+                "status": "error",
+                "error": "source_label and target_label are required for suggest_merge action",
+            }
+        return await label_suggest_merge(
+            source_label=source_label, target_label=target_label
+        )
+    elif action_lower == "merge":
+        if source_label is None or target_label is None:
+            return {
+                "status": "error",
+                "error": "source_label and target_label are required for merge action",
+            }
+        return await label_merge(
+            source_label=source_label,
+            target_label=target_label,
+            update_tickets=update_tickets,
+            dry_run=dry_run,
+        )
+    elif action_lower == "rename":
+        if old_name is None or new_name is None:
+            return {
+                "status": "error",
+                "error": "old_name and new_name are required for rename action",
+            }
+        return await label_rename(
+            old_name=old_name, new_name=new_name, update_tickets=update_tickets
+        )
+    elif action_lower == "cleanup_report":
+        return await label_cleanup_report(
+            include_spelling=include_spelling,
+            include_duplicates=include_duplicates,
+            include_unused=include_unused,
+        )
+    else:
+        valid_actions = [
+            "list",
+            "normalize",
+            "find_duplicates",
+            "suggest_merge",
+            "merge",
+            "rename",
+            "cleanup_report",
+        ]
+        return {
+            "status": "error",
+            "error": f"Invalid action '{action}'. Must be one of: {', '.join(valid_actions)}",
+            "valid_actions": valid_actions,
+            "hint": "Use label(action='list'|'normalize'|'find_duplicates'|'suggest_merge'|'merge'|'rename'|'cleanup_report', ...)",
+        }
+
+
 async def label_list(
     adapter_name: str | None = None,
     include_usage_count: bool = False,
+    limit: int = 100,
+    offset: int = 0,
 ) -> dict[str, Any]:
     """List all available labels/tags from the ticket system.
 
-    Retrieves labels from the configured adapter or a specific adapter if specified.
-    Optionally includes usage statistics showing how many tickets use each label.
-
-    Multi-Adapter Support:
-    - Without adapter_name: Uses default configured adapter
-    - With adapter_name: Uses specified adapter (requires multi-adapter setup)
-
-    Args:
-    ----
-        adapter_name: Optional adapter to query (e.g., "linear", "github", "jira")
-        include_usage_count: Include usage statistics for each label (default: False)
-
-    Returns:
-    -------
-        Dictionary containing:
-        - status: "completed" or "error"
-        - adapter: Adapter type that was queried
-        - adapter_name: Human-readable adapter name
-        - labels: List of label objects with id, name, and optionally usage_count
-        - total_labels: Total number of labels available
-        - error: Error message (if failed)
-
-    Example:
-    -------
-        >>> result = await label_list()
-        >>> print(result)
-        {
-            "status": "completed",
-            "adapter": "linear",
-            "adapter_name": "Linear",
-            "labels": [
-                {"id": "...", "name": "bug", "color": "#ff0000"},
-                {"id": "...", "name": "feature", "color": "#00ff00"}
-            ],
-            "total_labels": 2
-        }
-
-        >>> result = await label_list(include_usage_count=True)
-        >>> print(result["labels"][0])
-        {"id": "...", "name": "bug", "usage_count": 42}
+    .. deprecated::
+        Use label(action="list", ...) instead.
+        This tool will be removed in a future version.
 
+    Args: adapter_name (optional adapter), include_usage_count (default: False), limit (max: 500), offset (pagination)
+    Returns: LabelListResponse with labels array, count, pagination, estimated_tokens
+    See: docs/mcp-api-reference.md#label-response-format
     """
+    warnings.warn(
+        "label_list is deprecated. Use label(action='list', ...) instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     try:
+        # Validate and cap limits
+        if limit > 500:
+            logger.warning(f"Limit {limit} exceeds maximum 500, using 500")
+            limit = 500
+
+        if offset < 0:
+            logger.warning(f"Invalid offset {offset}, using 0")
+            offset = 0
+
+        # Warn about usage_count with large limits
+        if include_usage_count and limit > 100:
+            logger.warning(
+                f"Calculating usage counts for {limit} labels may be slow and use significant tokens. "
+                f"Consider reducing limit or omitting usage_count."
+            )
+
         # Get adapter (default or specified)
         if adapter_name:
             if not has_router():
@@ -118,10 +294,11 @@ async def label_list(
                 "error": f"Adapter {adapter.adapter_type} does not support label listing",
             }
 
-        # Get labels from adapter
-        labels = await adapter.list_labels()
+        # Get ALL labels from adapter (adapters don't support pagination for labels)
+        all_labels = await adapter.list_labels()
+        total_labels = len(all_labels)
 
-        # Add usage counts if requested
+        # Add usage counts if requested (before pagination)
         if include_usage_count:
             # Count label usage across all tickets
             try:
@@ -136,7 +313,7 @@ async def label_list(
                         label_counts[label_name] = label_counts.get(label_name, 0) + 1
 
                 # Enrich labels with usage counts
-                for label in labels:
+                for label in all_labels:
                     label_name = label.get("name", "")
                     label["usage_count"] = label_counts.get(label_name, 0)
 
@@ -144,13 +321,40 @@ async def label_list(
                 logger.warning(f"Failed to calculate usage counts: {e}")
                 # Continue without usage counts rather than failing
 
-        return {
+        # Apply manual pagination to labels
+        start_idx = offset
+        end_idx = offset + limit
+        paginated_labels = all_labels[start_idx:end_idx]
+        has_more = end_idx < total_labels
+
+        # Build response
+        response = {
             "status": "completed",
             **_build_adapter_metadata(adapter),
-            "labels": labels,
-            "total_labels": len(labels),
+            "labels": paginated_labels,
+            "total_labels": total_labels,
+            "count": len(paginated_labels),
+            "limit": limit,
+            "offset": offset,
+            "has_more": has_more,
         }
 
+        # Estimate tokens and warn if approaching limit
+        estimated_tokens = estimate_json_tokens(response)
+        response["estimated_tokens"] = estimated_tokens
+
+        if estimated_tokens > 15_000:
+            logger.warning(
+                f"Label list response contains ~{estimated_tokens} tokens. "
+                f"Consider reducing limit or omitting usage_count."
+            )
+            response["token_warning"] = (
+                f"Response approaching token limit ({estimated_tokens} tokens). "
+                f"Use smaller limit or omit usage_count."
+            )
+
+        return response
+
     except Exception as e:
         error_response = {
             "status": "error",
@@ -164,51 +368,25 @@ async def label_list(
         return error_response
 
 
-@mcp.tool()
 async def label_normalize(
     label_name: str,
     casing: str = "lowercase",
 ) -> dict[str, Any]:
-    """Normalize a label name using specified casing strategy.
+    """Normalize label name using casing strategy (lowercase, titlecase, uppercase, kebab-case, snake_case).
 
-    Applies consistent casing rules to label names for standardization.
-    Useful for ensuring labels follow a consistent naming convention.
-
-    Supported Casing Strategies:
-    - lowercase: Convert to lowercase (e.g., "Bug Report" → "bug report")
-    - titlecase: Convert to title case (e.g., "bug report" → "Bug Report")
-    - uppercase: Convert to uppercase (e.g., "bug report" → "BUG REPORT")
-    - kebab-case: Convert to kebab-case (e.g., "Bug Report" → "bug-report")
-    - snake_case: Convert to snake_case (e.g., "Bug Report" → "bug_report")
-
-    Args:
-    ----
-        label_name: Label name to normalize (required)
-        casing: Casing strategy to apply (default: "lowercase")
-
-    Returns:
-    -------
-        Dictionary containing:
-        - status: "completed" or "error"
-        - original: Original label name
-        - normalized: Normalized label name
-        - casing: Casing strategy applied
-        - changed: Whether normalization changed the label
-        - error: Error message (if failed)
-
-    Example:
-    -------
-        >>> result = await label_normalize("Bug Report", casing="kebab-case")
-        >>> print(result)
-        {
-            "status": "completed",
-            "original": "Bug Report",
-            "normalized": "bug-report",
-            "casing": "kebab-case",
-            "changed": True
-        }
+    .. deprecated::
+        Use label(action="normalize", ...) instead.
+        This tool will be removed in a future version.
 
+    Args: label_name (required), casing (default: "lowercase")
+    Returns: NormalizationResponse with original, normalized, casing, changed
+    See: docs/mcp-api-reference.md#label-normalization
     """
+    warnings.warn(
+        "label_normalize is deprecated. Use label(action='normalize', ...) instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     try:
         # Validate casing strategy
         try:
@@ -239,65 +417,25 @@ async def label_normalize(
         }
 
 
-@mcp.tool()
 async def label_find_duplicates(
     threshold: float = 0.85,
     limit: int = 50,
 ) -> dict[str, Any]:
-    """Find duplicate or similar labels in the ticket system.
+    """Find duplicate/similar labels using fuzzy matching (case, spelling, plurals).
 
-    Uses fuzzy matching to identify labels that are likely duplicates due to:
-    - Case variations (e.g., "bug" vs "Bug")
-    - Spelling variations (e.g., "feature" vs "feture")
-    - Plural forms (e.g., "bug" vs "bugs")
-    - Similar wording (e.g., "bug" vs "issue")
-
-    Similarity Scoring:
-    - 1.0: Exact match (case-insensitive)
-    - 0.95: Spelling correction or synonym
-    - 0.70-0.95: Fuzzy match based on string similarity
-
-    Args:
-    ----
-        threshold: Minimum similarity threshold (0.0-1.0, default: 0.85)
-        limit: Maximum number of duplicate pairs to return (default: 50)
-
-    Returns:
-    -------
-        Dictionary containing:
-        - status: "completed" or "error"
-        - adapter: Adapter type queried
-        - adapter_name: Human-readable adapter name
-        - duplicates: List of duplicate pairs with similarity scores
-        - total_duplicates: Total number of duplicate pairs found
-        - error: Error message (if failed)
-
-    Example:
-    -------
-        >>> result = await label_find_duplicates(threshold=0.80)
-        >>> print(result)
-        {
-            "status": "completed",
-            "adapter": "linear",
-            "adapter_name": "Linear",
-            "duplicates": [
-                {
-                    "label1": "bug",
-                    "label2": "Bug",
-                    "similarity": 1.0,
-                    "recommendation": "Merge 'Bug' into 'bug'"
-                },
-                {
-                    "label1": "feature",
-                    "label2": "feture",
-                    "similarity": 0.92,
-                    "recommendation": "Merge 'feture' into 'feature' (likely typo)"
-                }
-            ],
-            "total_duplicates": 2
-        }
+    .. deprecated::
+        Use label(action="find_duplicates", ...) instead.
+        This tool will be removed in a future version.
 
+    Args: threshold (0.0-1.0, default: 0.85), limit (default: 50)
+    Returns: DuplicateResponse with duplicates array (similarity scores, recommendations), total_duplicates
+    See: docs/mcp-api-reference.md#label-similarity-scoring
     """
+    warnings.warn(
+        "label_find_duplicates is deprecated. Use label(action='find_duplicates', ...) instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     try:
         adapter = get_adapter()
 
@@ -367,62 +505,41 @@ async def label_find_duplicates(
         return error_response
 
 
-@mcp.tool()
 async def label_suggest_merge(
     source_label: str,
     target_label: str,
 ) -> dict[str, Any]:
-    """Preview a label merge operation without executing it.
+    """Preview label merge operation (dry run, shows affected tickets).
 
-    Shows what would happen if source_label was merged into target_label,
-    including the number of tickets that would be affected.
-
-    Merge Operation Preview:
-    - All tickets with source_label will be updated to use target_label
-    - The source_label itself is NOT deleted from the system
-    - Tickets that already have both labels will only keep target_label
-
-    Args:
-    ----
-        source_label: Label to merge from (will be replaced on tickets)
-        target_label: Label to merge into (replacement label)
-
-    Returns:
-    -------
-        Dictionary containing:
-        - status: "completed" or "error"
-        - adapter: Adapter type
-        - adapter_name: Human-readable adapter name
-        - source_label: Source label name
-        - target_label: Target label name
-        - affected_tickets: Number of tickets that would be updated
-        - preview: List of ticket IDs that would be affected (up to 10)
-        - warning: Any warnings about the operation
-        - error: Error message (if failed)
-
-    Example:
-    -------
-        >>> result = await label_suggest_merge("Bug", "bug")
-        >>> print(result)
-        {
-            "status": "completed",
-            "adapter": "linear",
-            "adapter_name": "Linear",
-            "source_label": "Bug",
-            "target_label": "bug",
-            "affected_tickets": 15,
-            "preview": ["PROJ-123", "PROJ-456", "PROJ-789"],
-            "warning": null
-        }
+    .. deprecated::
+        Use label(action="suggest_merge", ...) instead.
+        This tool will be removed in a future version.
 
+    Args: source_label (from), target_label (to)
+    Returns: MergePreviewResponse with affected_tickets count, preview IDs (up to 10), warnings
+    See: docs/mcp-api-reference.md#label-merge-preview
     """
+    warnings.warn(
+        "label_suggest_merge is deprecated. Use label(action='suggest_merge', ...) instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     try:
         adapter = get_adapter()
 
         # Find all tickets with source label
         try:
             tickets = await adapter.search(
-                SearchQuery(query=f"label:{source_label}", limit=1000)
+                SearchQuery(
+                    query=f"label:{source_label}",
+                    limit=1000,
+                    state=None,
+                    priority=None,
+                    tags=None,
+                    assignee=None,
+                    project=None,
+                    offset=0,
+                )
             )
         except Exception:
             # Fallback: list all tickets and filter manually
@@ -462,73 +579,27 @@ async def label_suggest_merge(
         return error_response
 
 
-@mcp.tool()
 async def label_merge(
     source_label: str,
     target_label: str,
     update_tickets: bool = True,
     dry_run: bool = False,
 ) -> dict[str, Any]:
-    """Merge source label into target label across all tickets.
+    """Merge source label into target across all tickets (does NOT delete source definition).
 
-    Replaces all occurrences of source_label with target_label on affected tickets.
-    This operation updates tickets but does NOT delete the source label definition.
-
-    Merge Behavior:
-    - Tickets with source_label: Label replaced with target_label
-    - Tickets with both labels: Keep only target_label (remove duplicate)
-    - Tickets with neither: No changes
-    - Source label definition: Remains in system (use adapter's label delete API separately)
-
-    Safety Features:
-    - dry_run mode: Preview changes without applying them
-    - update_tickets=False: Only show what would change, don't modify anything
-
-    Args:
-    ----
-        source_label: Label to merge from (will be replaced on tickets)
-        target_label: Label to merge into (replacement label)
-        update_tickets: Actually update tickets (default: True)
-        dry_run: Preview mode - show changes without applying (default: False)
-
-    Returns:
-    -------
-        Dictionary containing:
-        - status: "completed" or "error"
-        - adapter: Adapter type
-        - adapter_name: Human-readable adapter name
-        - tickets_updated: Number of tickets modified
-        - tickets_skipped: Number of tickets skipped (already had target)
-        - dry_run: Whether this was a dry run
-        - changes: List of changes made (up to 20)
-        - error: Error message (if failed)
-
-    Example:
-    -------
-        >>> # Dry run first
-        >>> result = await label_merge("Bug", "bug", dry_run=True)
-        >>> print(result)
-        {
-            "status": "completed",
-            "dry_run": True,
-            "tickets_updated": 0,
-            "tickets_would_update": 15,
-            "changes": [
-                {"ticket_id": "PROJ-123", "action": "Replace 'Bug' with 'bug'"}
-            ]
-        }
-
-        >>> # Execute merge
-        >>> result = await label_merge("Bug", "bug", update_tickets=True)
-        >>> print(result)
-        {
-            "status": "completed",
-            "tickets_updated": 15,
-            "tickets_skipped": 3,
-            "changes": [...]
-        }
+    .. deprecated::
+        Use label(action="merge", ...) instead.
+        This tool will be removed in a future version.
 
+    Args: source_label (from), target_label (to), update_tickets (default: True), dry_run (default: False)
+    Returns: MergeResponse with tickets_updated, tickets_skipped, changes array (up to 20)
+    See: docs/mcp-api-reference.md#label-merge-behavior
     """
+    warnings.warn(
+        "label_merge is deprecated. Use label(action='merge', ...) instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     try:
         adapter = get_adapter()
 
@@ -542,7 +613,16 @@ async def label_merge(
         # Find all tickets with source label
         try:
             tickets = await adapter.search(
-                SearchQuery(query=f"label:{source_label}", limit=1000)
+                SearchQuery(
+                    query=f"label:{source_label}",
+                    limit=1000,
+                    state=None,
+                    priority=None,
+                    tags=None,
+                    assignee=None,
+                    project=None,
+                    offset=0,
+                )
             )
         except Exception:
             # Fallback: list all tickets and filter manually
@@ -635,55 +715,28 @@ async def label_merge(
         return error_response
 
 
-@mcp.tool()
 async def label_rename(
     old_name: str,
     new_name: str,
     update_tickets: bool = True,
 ) -> dict[str, Any]:
-    """Rename a label across all tickets.
+    """Rename label across all tickets (alias for label_merge, semantic variant for typo fixes).
 
-    Updates all tickets using old_name to use new_name instead.
-    This is effectively an alias for label_merge with different semantics.
-
-    Use label_rename when:
-    - Fixing typos in label names
-    - Standardizing label naming conventions
-    - Rebranding labels for clarity
-
-    Args:
-    ----
-        old_name: Current label name to rename
-        new_name: New label name to use
-        update_tickets: Actually update tickets (default: True)
-
-    Returns:
-    -------
-        Dictionary containing:
-        - status: "completed" or "error"
-        - adapter: Adapter type
-        - adapter_name: Human-readable adapter name
-        - tickets_updated: Number of tickets modified
-        - old_name: Original label name
-        - new_name: New label name
-        - error: Error message (if failed)
-
-    Example:
-    -------
-        >>> result = await label_rename("feture", "feature", update_tickets=True)
-        >>> print(result)
-        {
-            "status": "completed",
-            "adapter": "linear",
-            "adapter_name": "Linear",
-            "old_name": "feture",
-            "new_name": "feature",
-            "tickets_updated": 8
-        }
+    .. deprecated::
+        Use label(action="rename", ...) instead.
+        This tool will be removed in a future version.
 
+    Args: old_name (current), new_name (replacement), update_tickets (default: True)
+    Returns: RenameResponse with tickets_updated, old_name, new_name
+    See: docs/mcp-api-reference.md#label-merge-behavior
     """
+    warnings.warn(
+        "label_rename is deprecated. Use label(action='rename', ...) instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     # Delegate to label_merge (rename is just a semantic alias)
-    result = await label_merge(
+    result: dict[str, Any] = await label_merge(
         source_label=old_name,
         target_label=new_name,
         update_tickets=update_tickets,
@@ -700,67 +753,26 @@ async def label_rename(
     return result
 
 
-@mcp.tool()
 async def label_cleanup_report(
     include_spelling: bool = True,
     include_duplicates: bool = True,
     include_unused: bool = True,
 ) -> dict[str, Any]:
-    """Generate comprehensive label cleanup report with actionable recommendations.
+    """Generate label cleanup report (spelling errors, duplicates, unused labels with recommendations).
 
-    Analyzes all labels in the ticket system and identifies:
-    - Spelling errors and typos (using spelling dictionary)
-    - Duplicate or similar labels (using fuzzy matching)
-    - Unused labels (labels with zero tickets)
-
-    Report Sections:
-    1. Spelling Issues: Labels that match known misspellings
-    2. Duplicate Labels: Similar labels that should be consolidated
-    3. Unused Labels: Labels not assigned to any tickets
-
-    Each issue includes actionable recommendations and severity ratings.
-
-    Args:
-    ----
-        include_spelling: Include spelling error analysis (default: True)
-        include_duplicates: Include duplicate detection (default: True)
-        include_unused: Include unused label detection (default: True)
-
-    Returns:
-    -------
-        Dictionary containing:
-        - status: "completed" or "error"
-        - adapter: Adapter type
-        - adapter_name: Human-readable adapter name
-        - summary: High-level statistics
-        - spelling_issues: List of spelling problems (if enabled)
-        - duplicate_groups: List of duplicate label groups (if enabled)
-        - unused_labels: List of unused labels (if enabled)
-        - recommendations: Prioritized list of actions to take
-        - error: Error message (if failed)
-
-    Example:
-    -------
-        >>> result = await label_cleanup_report()
-        >>> print(result["summary"])
-        {
-            "total_labels": 45,
-            "spelling_issues": 3,
-            "duplicate_groups": 5,
-            "unused_labels": 8,
-            "estimated_cleanup_savings": "16 labels can be consolidated"
-        }
-
-        >>> print(result["recommendations"][0])
-        {
-            "priority": "high",
-            "category": "spelling",
-            "action": "Rename 'feture' to 'feature'",
-            "affected_tickets": 12,
-            "command": "label_rename(old_name='feture', new_name='feature')"
-        }
+    .. deprecated::
+        Use label(action="cleanup_report", ...) instead.
+        This tool will be removed in a future version.
 
+    Args: include_spelling (default: True), include_duplicates (default: True), include_unused (default: True)
+    Returns: CleanupReportResponse with summary, spelling_issues, duplicate_groups, unused_labels, recommendations (prioritized)
+    See: docs/mcp-api-reference.md#label-cleanup-report
     """
+    warnings.warn(
+        "label_cleanup_report is deprecated. Use label(action='cleanup_report', ...) instead.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
     try:
         adapter = get_adapter()
 
@@ -783,10 +795,10 @@ async def label_cleanup_report(
         tickets = await adapter.list(limit=1000)
 
         # Initialize report sections
-        spelling_issues = []
-        duplicate_groups = []
-        unused_labels = []
-        recommendations = []
+        spelling_issues: list[dict[str, Any]] = []
+        duplicate_groups: list[dict[str, Any]] = []
+        unused_labels: list[dict[str, Any]] = []
+        recommendations: list[dict[str, Any]] = []
 
         # 1. Spelling Issues Analysis
         if include_spelling:
@@ -856,7 +868,7 @@ async def label_cleanup_report(
 
         # 3. Unused Labels Analysis
         if include_unused:
-            label_usage = dict.fromkeys(label_names, 0)
+            label_usage: dict[str, int] = dict.fromkeys(label_names, 0)
             for ticket in tickets:
                 for tag in ticket.tags or []:
                     if tag in label_usage:
@@ -875,16 +887,16 @@ async def label_cleanup_report(
                         "category": "unused",
                         "action": f"Review {len(unused_labels)} unused labels for deletion",
                         "affected_tickets": 0,
-                        "labels": [lbl["name"] for lbl in unused_labels[:10]],
+                        "labels": [str(lbl["name"]) for lbl in unused_labels[:10]],
                     }
                 )
 
         # Sort recommendations by priority
-        priority_order = {"high": 0, "medium": 1, "low": 2}
-        recommendations.sort(key=lambda x: priority_order.get(x["priority"], 3))
+        priority_order: dict[str, int] = {"high": 0, "medium": 1, "low": 2}
+        recommendations.sort(key=lambda x: priority_order.get(str(x["priority"]), 3))
 
         # Build summary
-        summary = {
+        summary: dict[str, Any] = {
             "total_labels": len(label_names),
             "spelling_issues": len(spelling_issues),
             "duplicate_groups": len(duplicate_groups),
@@ -894,7 +906,12 @@ async def label_cleanup_report(
 
         # Calculate potential consolidation
         consolidation_potential = sum(
-            len(variants) for variants in (grp["variants"] for grp in duplicate_groups)
+            (
+                len(list(grp["variants"]))
+                if isinstance(grp["variants"], list | tuple)
+                else 0
+            )
+            for grp in duplicate_groups
         ) + len(spelling_issues)
 
         if consolidation_potential > 0:
