@@ -1,8 +1,7 @@
 """User-specific ticket management tools.
 
 This module provides tools for managing tickets from a user's perspective,
-including listing assigned tickets and transitioning tickets through workflow
-states with validation.
+including transitioning tickets through workflow states with validation.
 
 Design Decision: Workflow State Validation
 ------------------------------------------
@@ -20,17 +19,13 @@ Valid workflow transitions:
 - CLOSED → (no transitions, terminal state)
 
 Performance Considerations:
-- get_my_tickets uses adapter's native filtering when available
-- Falls back to client-side filtering for adapters without assignee filter
 - State transition validation is O(1) lookup in predefined state machine
 """
 
-from pathlib import Path
 from typing import Any
 
 from ....core.adapter import BaseAdapter
 from ....core.models import TicketState
-from ....core.project_config import ConfigResolver, TicketerConfig
 from ....core.state_matcher import get_state_matcher
 from ..server_sdk import get_adapter, mcp
 
@@ -49,165 +44,13 @@ def _build_adapter_metadata(
     return metadata
 
 
-def get_config_resolver() -> ConfigResolver:
-    """Get configuration resolver for current project.
-
-    Returns:
-        ConfigResolver instance for current working directory
-
-    """
-    return ConfigResolver(project_path=Path.cwd())
-
-
-@mcp.tool()
-async def get_my_tickets(
-    state: str | None = None,
-    limit: int = 10,
-) -> dict[str, Any]:
-    """Get tickets assigned to the configured default user.
-
-    Retrieves tickets assigned to the user specified in default_user configuration.
-    Requires default_user to be set via config_set_default_user().
-
-    Args:
-        state: Optional state filter - must be one of: open, in_progress, ready,
-            tested, done, closed, waiting, blocked
-        limit: Maximum number of tickets to return (default: 10, max: 100)
-
-    Returns:
-        Dictionary containing:
-        - status: "completed" or "error"
-        - tickets: List of ticket objects assigned to user
-        - count: Number of tickets returned
-        - user: User ID that was queried
-        - state_filter: State filter applied (if any)
-        - error: Error details (if failed)
-
-    Example:
-        >>> result = await get_my_tickets(state="in_progress", limit=5)
-        >>> print(result)
-        {
-            "status": "completed",
-            "tickets": [
-                {"id": "TICKET-1", "title": "Fix bug", "state": "in_progress"},
-                {"id": "TICKET-2", "title": "Add feature", "state": "in_progress"}
-            ],
-            "count": 2,
-            "user": "user@example.com",
-            "state_filter": "in_progress"
-        }
-
-    Error Conditions:
-        - No default user configured: Returns error with setup instructions
-        - Invalid state: Returns error with valid state options
-        - Adapter query failure: Returns error with details
-
-    Usage Notes:
-        - Requires default_user to be set in configuration
-        - Use config_set_default_user() to configure the user first
-        - Limit is capped at 100 to prevent performance issues
-
-    """
-    try:
-        # Validate limit
-        if limit > 100:
-            limit = 100
-
-        # Load configuration to get default user
-        resolver = get_config_resolver()
-        config = resolver.load_project_config() or TicketerConfig()
-
-        if not config.default_user:
-            return {
-                "status": "error",
-                "error": "No default user configured. Use config_set_default_user() to set a default user first.",
-                "setup_command": "config_set_default_user",
-            }
-
-        # Validate state if provided
-        state_filter = None
-        if state is not None:
-            try:
-                state_filter = TicketState(state.lower())
-            except ValueError:
-                valid_states = [s.value for s in TicketState]
-                return {
-                    "status": "error",
-                    "error": f"Invalid state '{state}'. Must be one of: {', '.join(valid_states)}",
-                    "valid_states": valid_states,
-                }
-
-        # Build filters
-        filters: dict[str, Any] = {"assignee": config.default_user}
-        if state_filter:
-            filters["state"] = state_filter
-
-        # Query adapter
-        adapter = get_adapter()
-        tickets = await adapter.list(limit=limit, offset=0, filters=filters)
-
-        return {
-            "status": "completed",
-            **_build_adapter_metadata(adapter),
-            "tickets": [ticket.model_dump() for ticket in tickets],
-            "count": len(tickets),
-            "user": config.default_user,
-            "state_filter": state if state else "all",
-            "limit": limit,
-        }
-    except Exception as e:
-        return {
-            "status": "error",
-            "error": f"Failed to retrieve tickets: {str(e)}",
-        }
-
-
 @mcp.tool()
 async def get_available_transitions(ticket_id: str) -> dict[str, Any]:
-    """Get valid next states for a ticket based on workflow rules.
-
-    Retrieves the ticket's current state and returns all valid target states
-    according to the defined workflow state machine. This helps AI agents and
-    users understand which state transitions are allowed.
-
-    Args:
-        ticket_id: Unique identifier of the ticket
-
-    Returns:
-        Dictionary containing:
-        - status: "completed" or "error"
-        - ticket_id: ID of the queried ticket
-        - current_state: Current workflow state
-        - available_transitions: List of valid target states
-        - transition_descriptions: Human-readable descriptions of each transition
-        - error: Error details (if failed)
-
-    Example:
-        >>> result = await get_available_transitions("TICKET-123")
-        >>> print(result)
-        {
-            "status": "completed",
-            "ticket_id": "TICKET-123",
-            "current_state": "in_progress",
-            "available_transitions": ["ready", "waiting", "blocked", "open"],
-            "transition_descriptions": {
-                "ready": "Mark work as complete and ready for review",
-                "waiting": "Pause work while waiting for external dependency",
-                "blocked": "Work is blocked by an impediment",
-                "open": "Move back to backlog"
-            }
-        }
-
-    Error Conditions:
-        - Ticket not found: Returns error with ticket ID
-        - Adapter query failure: Returns error with details
-        - Terminal state (CLOSED): Returns empty transitions list
-
-    Usage Notes:
-        - CLOSED is a terminal state with no valid transitions
-        - Use this before ticket_transition() to validate intended state change
-        - Transition validation prevents workflow violations
+    """Get valid next states for ticket based on workflow state machine.
 
+    Args: ticket_id (required)
+    Returns: TransitionResponse with current_state, available_transitions, transition_descriptions, is_terminal
+    See: docs/ticket-workflows.md#valid-state-transitions
     """
     try:
         # Get ticket from adapter
@@ -268,95 +111,11 @@ async def ticket_transition(
     comment: str | None = None,
     auto_confirm: bool = True,
 ) -> dict[str, Any]:
-    """Move ticket through workflow with validation and optional comment.
-
-    Supports natural language state inputs with semantic matching.
-    Transitions a ticket to a new state, validating the transition against the
-    defined workflow rules. Optionally adds a comment explaining the transition.
-
-    Semantic State Matching:
-        - Accepts natural language: "working on it" → IN_PROGRESS
-        - Handles typos: "reviw" → READY
-        - Provides suggestions for ambiguous inputs
-        - Confidence-based handling (high/medium/low)
-
-    Workflow State Machine:
-        OPEN → IN_PROGRESS, WAITING, BLOCKED, CLOSED
-        IN_PROGRESS → READY, WAITING, BLOCKED, OPEN
-        READY → TESTED, IN_PROGRESS, BLOCKED
-        TESTED → DONE, IN_PROGRESS
-        DONE → CLOSED
-        WAITING → OPEN, IN_PROGRESS, CLOSED
-        BLOCKED → OPEN, IN_PROGRESS, CLOSED
-        CLOSED → (no transitions)
-
-    Args:
-        ticket_id: Unique identifier of the ticket to transition
-        to_state: Target state (supports natural language!)
-            Examples: "working on it", "needs review", "finished", "review"
-        comment: Optional comment explaining the transition reason
-        auto_confirm: Auto-apply high confidence matches (default: True)
-
-    Returns:
-        Dictionary containing:
-        - status: "completed", "needs_confirmation", or "error"
-        - ticket: Updated ticket object with new state (if completed)
-        - previous_state: State before transition
-        - new_state: State after transition
-        - matched_state: Matched state from input (if semantic match used)
-        - confidence: Confidence score (0.0-1.0) for semantic matches
-        - original_input: Original user input
-        - suggestions: Alternative matches (for ambiguous inputs)
-        - comment_added: Whether a comment was added (if applicable)
-        - error: Error details (if failed)
-
-    Example:
-        >>> # Natural language input
-        >>> result = await ticket_transition(
-        ...     "TICKET-123",
-        ...     "working on it",
-        ...     "Started implementation"
-        ... )
-        >>> print(result)
-        {
-            "status": "completed",
-            "ticket": {"id": "TICKET-123", "state": "in_progress", ...},
-            "previous_state": "open",
-            "new_state": "in_progress",
-            "matched_state": "in_progress",
-            "confidence": 0.95,
-            "original_input": "working on it",
-            "comment_added": True
-        }
-
-        >>> # Ambiguous input returns suggestions
-        >>> result = await ticket_transition("TICKET-123", "rev")
-        >>> print(result)
-        {
-            "status": "needs_confirmation",
-            "matched_state": "ready",
-            "confidence": 0.75,
-            "suggestions": [
-                {"state": "ready", "confidence": 0.75},
-                {"state": "reviewed", "confidence": 0.60}
-            ]
-        }
-
-    Error Conditions:
-        - Ticket not found: Returns error with ticket ID
-        - Invalid transition: Returns error with valid options
-        - Invalid state name: Returns error with valid states
-        - Adapter update failure: Returns error with details
-
-    Usage Notes:
-        - Use get_available_transitions() first to see valid options
-        - Comments are adapter-dependent (some may not support them)
-        - Validation prevents workflow violations
-        - Terminal state (CLOSED) has no valid transitions
-        - High confidence (≥0.90): Auto-applied
-        - Medium confidence (0.70-0.89): Needs confirmation (if auto_confirm=False)
-        - Low confidence (<0.70): Returns suggestions
+    """Move ticket through workflow with validation and semantic matching (natural language support).
 
+    Args: ticket_id (required), to_state (supports natural language like "working on it"), comment (optional), auto_confirm (default: True)
+    Returns: TransitionResponse with status, ticket, previous_state, new_state, matched_state, confidence, suggestions (if ambiguous)
+    See: docs/ticket-workflows.md#semantic-state-matching, docs/ticket-workflows.md#valid-state-transitions
     """
     try:
         # Get ticket from adapter
@@ -507,7 +266,59 @@ async def ticket_transition(
                 # Log but don't fail the transition
                 comment_added = False
 
-        return {
+        # Auto project update hook (1M-315)
+        # Trigger automatic project update if enabled and ticket has parent epic
+        auto_update_result = None
+        try:
+            from pathlib import Path
+
+            from ....automation.project_updates import AutoProjectUpdateManager
+            from ....core.project_config import ConfigResolver
+
+            # Load config
+            resolver = ConfigResolver(project_path=Path.cwd())
+            config_obj = resolver.load_project_config()
+            config_dict = config_obj.to_dict() if config_obj else {}
+
+            # Check if auto updates enabled
+            auto_updates_mgr = AutoProjectUpdateManager(config_dict, adapter)
+            if auto_updates_mgr.is_enabled():
+                # Check if ticket has parent_epic
+                parent_epic = (
+                    updated.parent_epic if hasattr(updated, "parent_epic") else None
+                )
+
+                if parent_epic:
+                    # Only trigger on configured frequency
+                    update_frequency = auto_updates_mgr.get_update_frequency()
+                    should_trigger = update_frequency == "on_transition"
+
+                    # For "on_completion", only trigger if transitioned to done/closed
+                    if update_frequency == "on_completion":
+                        from ....core.models import TicketState as TSEnum
+
+                        should_trigger = target_state in (TSEnum.DONE, TSEnum.CLOSED)
+
+                    if should_trigger:
+                        auto_update_result = (
+                            await auto_updates_mgr.create_transition_update(
+                                ticket_id=ticket_id,
+                                ticket_title=updated.title or "",
+                                old_state=current_state.value,
+                                new_state=target_state.value,
+                                parent_epic=parent_epic,
+                            )
+                        )
+        except Exception as e:
+            # Log error but don't block the transition
+            import logging
+
+            logging.getLogger(__name__).warning(
+                f"Auto project update failed (non-blocking): {e}"
+            )
+
+        # Build final response
+        final_response = {
             **response,
             **_build_adapter_metadata(adapter, ticket_id),
             "status": "completed",
@@ -517,6 +328,12 @@ async def ticket_transition(
             "comment_added": comment_added,
             "message": f"Ticket {ticket_id} transitioned from {current_state.value} to {target_state.value}",
         }
+
+        # Include auto update result if applicable
+        if auto_update_result:
+            final_response["auto_project_update"] = auto_update_result
+
+        return final_response
     except Exception as e:
         return {
             "status": "error",
