@@ -12,7 +12,7 @@ from mcp_ticketer.core.models import TicketState
 class TestLinearAdapterInit:
     """Test Linear adapter initialization."""
 
-    def test_init_with_api_key_and_team_id(self):
+    def test_init_with_api_key_and_team_id(self) -> None:
         """Test initialization with API key and team ID."""
         config = {"api_key": "lin_api_test_key_12345", "team_id": "team-123"}
 
@@ -23,7 +23,7 @@ class TestLinearAdapterInit:
         assert adapter.team_key is None
         assert adapter.api_url == "https://api.linear.app/graphql"
 
-    def test_init_with_api_key_and_team_key(self):
+    def test_init_with_api_key_and_team_key(self) -> None:
         """Test initialization with API key and team key."""
         config = {"api_key": "lin_api_test_key_12345", "team_key": "TEST"}
 
@@ -32,7 +32,7 @@ class TestLinearAdapterInit:
         assert adapter.team_key == "TEST"
         assert adapter.team_id is None
 
-    def test_init_with_bearer_prefix(self):
+    def test_init_with_bearer_prefix(self) -> None:
         """Test initialization when API key already has Bearer prefix."""
         config = {"api_key": "Bearer lin_api_test_key_12345", "team_id": "team-123"}
 
@@ -41,7 +41,7 @@ class TestLinearAdapterInit:
         assert adapter.api_key == "lin_api_test_key_12345"
 
     @patch.dict("os.environ", {}, clear=True)
-    def test_init_missing_api_key(self):
+    def test_init_missing_api_key(self) -> None:
         """Test initialization without API key."""
         config = {"team_id": "team-123"}
 
@@ -50,7 +50,7 @@ class TestLinearAdapterInit:
 
         assert "Linear API key is required" in str(exc_info.value)
 
-    def test_init_missing_team_info(self):
+    def test_init_missing_team_info(self) -> None:
         """Test initialization without team key or ID."""
         config = {"api_key": "lin_api_test_key_12345"}
 
@@ -60,7 +60,7 @@ class TestLinearAdapterInit:
         assert "Either team_key or team_id must be provided" in str(exc_info.value)
 
     @patch.dict("os.environ", {"LINEAR_API_KEY": "lin_api_env_key_12345"})
-    def test_init_with_env_api_key(self):
+    def test_init_with_env_api_key(self) -> None:
         """Test initialization with API key from environment."""
         config = {"team_id": "team-123"}
 
@@ -68,7 +68,7 @@ class TestLinearAdapterInit:
 
         assert adapter.api_key == "lin_api_env_key_12345"
 
-    def test_init_with_custom_api_url(self):
+    def test_init_with_custom_api_url(self) -> None:
         """Test initialization with custom API URL."""
         config = {
             "api_key": "lin_api_test_key_12345",
@@ -85,7 +85,7 @@ class TestLinearAdapterInit:
 class TestLinearAdapterValidation:
     """Test Linear adapter validation methods."""
 
-    def test_validate_credentials_success(self):
+    def test_validate_credentials_success(self) -> None:
         """Test successful credential validation."""
         config = {"api_key": "lin_api_test_key_12345", "team_id": "team-123"}
         adapter = LinearAdapter(config)
@@ -95,7 +95,7 @@ class TestLinearAdapterValidation:
         assert is_valid is True
         assert error_message == ""
 
-    def test_validate_credentials_missing_api_key(self):
+    def test_validate_credentials_missing_api_key(self) -> None:
         """Test credential validation with missing API key."""
 
         # Create adapter with missing API key by bypassing __init__ validation
@@ -109,7 +109,7 @@ class TestLinearAdapterValidation:
         assert is_valid is False
         assert "Linear API key is required" in error_message
 
-    def test_validate_credentials_missing_team_info(self):
+    def test_validate_credentials_missing_team_info(self) -> None:
         """Test credential validation with missing team info."""
 
         # Create adapter with missing team info by bypassing __init__ validation
@@ -128,7 +128,7 @@ class TestLinearAdapterValidation:
 class TestLinearAdapterStateMapping:
     """Test Linear adapter state mapping."""
 
-    def test_get_state_mapping_without_workflow_states(self):
+    def test_get_state_mapping_without_workflow_states(self) -> None:
         """Test state mapping when workflow states are not loaded."""
         config = {"api_key": "lin_api_test_key_12345", "team_id": "team-123"}
         adapter = LinearAdapter(config)
@@ -144,26 +144,36 @@ class TestLinearAdapterStateMapping:
         assert mapping[TicketState.DONE] == "completed"
         assert mapping[TicketState.CLOSED] == "canceled"
 
-    def test_get_state_mapping_with_workflow_states(self):
+    def test_get_state_mapping_with_workflow_states(self) -> None:
         """Test state mapping when workflow states are loaded."""
         config = {"api_key": "lin_api_test_key_12345", "team_id": "team-123"}
         adapter = LinearAdapter(config)
 
         # Mock loaded workflow states
+        # _workflow_states is keyed by universal_state.value (e.g., "open")
+        # and contains state UUIDs directly (not dict with "id" key)
         adapter._workflow_states = {
-            "unstarted": {"id": "state-1", "name": "To Do"},
-            "started": {"id": "state-2", "name": "In Progress"},
-            "completed": {"id": "state-3", "name": "Done"},
-            "canceled": {"id": "state-4", "name": "Canceled"},
+            "open": "state-uuid-1",
+            "in_progress": "state-uuid-2",
+            "done": "state-uuid-3",
+            "closed": "state-uuid-4",
+            "ready": "state-uuid-5",
+            "tested": "state-uuid-6",
+            "waiting": "state-uuid-7",
+            "blocked": "state-uuid-8",
         }
 
         mapping = adapter._get_state_mapping()
 
-        # Should return ID-based mapping
-        assert mapping[TicketState.OPEN] == "state-1"
-        assert mapping[TicketState.IN_PROGRESS] == "state-2"
-        assert mapping[TicketState.DONE] == "state-3"
-        assert mapping[TicketState.CLOSED] == "state-4"
+        # Should return UUID-based mapping
+        assert mapping[TicketState.OPEN] == "state-uuid-1"
+        assert mapping[TicketState.IN_PROGRESS] == "state-uuid-2"
+        assert mapping[TicketState.DONE] == "state-uuid-3"
+        assert mapping[TicketState.CLOSED] == "state-uuid-4"
+        assert mapping[TicketState.READY] == "state-uuid-5"
+        assert mapping[TicketState.TESTED] == "state-uuid-6"
+        assert mapping[TicketState.WAITING] == "state-uuid-7"
+        assert mapping[TicketState.BLOCKED] == "state-uuid-8"
 
 
 @pytest.mark.unit
@@ -332,9 +342,9 @@ class TestLinearAdapterInitialization:
             "team": {
                 "states": {
                     "nodes": [
-                        {"id": "state-1", "type": "unstarted", "position": 1},
-                        {"id": "state-2", "type": "started", "position": 1},
-                        {"id": "state-3", "type": "completed", "position": 1},
+                        {"id": "state-1", "name": "Todo", "type": "unstarted", "position": 1},
+                        {"id": "state-2", "name": "In Progress", "type": "started", "position": 1},
+                        {"id": "state-3", "name": "Done", "type": "completed", "position": 1},
                     ]
                 }
             }
@@ -343,10 +353,17 @@ class TestLinearAdapterInitialization:
         with patch.object(adapter.client, "execute_query", return_value=mock_result):
             await adapter._load_workflow_states("team-123")
 
+        # Verify workflow states were loaded with semantic mapping
+        # (Uses universal state names, not Linear type names)
         assert adapter._workflow_states is not None
-        assert "unstarted" in adapter._workflow_states
-        assert "started" in adapter._workflow_states
-        assert "completed" in adapter._workflow_states
+        assert "open" in adapter._workflow_states  # Maps to "Todo" (unstarted type)
+        assert "in_progress" in adapter._workflow_states  # Maps to "In Progress" (started type)
+        assert "done" in adapter._workflow_states  # Maps to "Done" (completed type)
+
+        # Verify mapping correctness
+        assert adapter._workflow_states["open"] == "state-1"
+        assert adapter._workflow_states["in_progress"] == "state-2"
+        assert adapter._workflow_states["done"] == "state-3"
 
 
 @pytest.mark.unit
