@@ -23,14 +23,14 @@ from mcp_ticketer.core.models import TicketState
 class TestMCPTicketerError:
     """Test base MCPTicketerError exception."""
 
-    def test_create_base_error(self):
+    def test_create_base_error(self) -> None:
         """Test creating the base error."""
         error = MCPTicketerError("Test error")
 
         assert str(error) == "Test error"
         assert isinstance(error, Exception)
 
-    def test_raise_base_error(self):
+    def test_raise_base_error(self) -> None:
         """Test raising the base error."""
         with pytest.raises(MCPTicketerError) as exc_info:
             raise MCPTicketerError("Test error")
@@ -42,7 +42,7 @@ class TestMCPTicketerError:
 class TestAdapterError:
     """Test AdapterError exception."""
 
-    def test_create_adapter_error(self):
+    def test_create_adapter_error(self) -> None:
         """Test creating adapter error with minimal args."""
         error = AdapterError("Connection failed", "linear")
 
@@ -51,7 +51,7 @@ class TestAdapterError:
         assert "[linear]" in str(error)
         assert "Connection failed" in str(error)
 
-    def test_adapter_error_with_original_error(self):
+    def test_adapter_error_with_original_error(self) -> None:
         """Test adapter error with original exception."""
         original = ValueError("Invalid API key")
         error = AdapterError("Auth failed", "jira", original)
@@ -63,7 +63,7 @@ class TestAdapterError:
         assert "caused by:" in str(error)
         assert "Invalid API key" in str(error)
 
-    def test_adapter_error_inheritance(self):
+    def test_adapter_error_inheritance(self) -> None:
         """Test that AdapterError inherits from MCPTicketerError."""
         error = AdapterError("Test", "test_adapter")
 
@@ -71,7 +71,7 @@ class TestAdapterError:
         assert isinstance(error, MCPTicketerError)
         assert isinstance(error, Exception)
 
-    def test_raise_adapter_error(self):
+    def test_raise_adapter_error(self) -> None:
         """Test raising adapter error."""
         with pytest.raises(AdapterError) as exc_info:
             raise AdapterError("Test error", "test_adapter")
@@ -83,7 +83,7 @@ class TestAdapterError:
 class TestAuthenticationError:
     """Test AuthenticationError exception."""
 
-    def test_create_authentication_error(self):
+    def test_create_authentication_error(self) -> None:
         """Test creating authentication error."""
         error = AuthenticationError("Invalid credentials", "github")
 
@@ -91,7 +91,7 @@ class TestAuthenticationError:
         assert "[github]" in str(error)
         assert "Invalid credentials" in str(error)
 
-    def test_authentication_error_inheritance(self):
+    def test_authentication_error_inheritance(self) -> None:
         """Test that AuthenticationError inherits from AdapterError."""
         error = AuthenticationError("Auth failed", "linear")
 
@@ -99,7 +99,7 @@ class TestAuthenticationError:
         assert isinstance(error, AdapterError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_authentication_error(self):
+    def test_raise_authentication_error(self) -> None:
         """Test raising authentication error."""
         with pytest.raises(AuthenticationError) as exc_info:
             raise AuthenticationError("Unauthorized", "jira")
@@ -111,7 +111,7 @@ class TestAuthenticationError:
 class TestRateLimitError:
     """Test RateLimitError exception."""
 
-    def test_create_rate_limit_error_without_retry_after(self):
+    def test_create_rate_limit_error_without_retry_after(self) -> None:
         """Test creating rate limit error without retry_after."""
         error = RateLimitError("Rate limit exceeded", "github")
 
@@ -120,7 +120,7 @@ class TestRateLimitError:
         assert "[github]" in str(error)
         assert "Rate limit exceeded" in str(error)
 
-    def test_create_rate_limit_error_with_retry_after(self):
+    def test_create_rate_limit_error_with_retry_after(self) -> None:
         """Test creating rate limit error with retry_after."""
         error = RateLimitError("Too many requests", "linear", retry_after=60)
 
@@ -129,7 +129,7 @@ class TestRateLimitError:
         assert "[linear]" in str(error)
         assert "Too many requests" in str(error)
 
-    def test_rate_limit_error_with_original_error(self):
+    def test_rate_limit_error_with_original_error(self) -> None:
         """Test rate limit error with original exception."""
         original = ConnectionError("HTTP 429")
         error = RateLimitError(
@@ -142,7 +142,7 @@ class TestRateLimitError:
         assert "caused by:" in str(error)
         assert "HTTP 429" in str(error)
 
-    def test_rate_limit_error_inheritance(self):
+    def test_rate_limit_error_inheritance(self) -> None:
         """Test that RateLimitError inherits from AdapterError."""
         error = RateLimitError("Rate limit", "test", retry_after=10)
 
@@ -150,7 +150,7 @@ class TestRateLimitError:
         assert isinstance(error, AdapterError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_rate_limit_error(self):
+    def test_raise_rate_limit_error(self) -> None:
         """Test raising rate limit error."""
         with pytest.raises(RateLimitError) as exc_info:
             raise RateLimitError("Too fast", "test", retry_after=120)
@@ -162,7 +162,7 @@ class TestRateLimitError:
 class TestValidationError:
     """Test ValidationError exception."""
 
-    def test_create_validation_error_minimal(self):
+    def test_create_validation_error_minimal(self) -> None:
         """Test creating validation error with only message."""
         error = ValidationError("Invalid data")
 
@@ -170,7 +170,7 @@ class TestValidationError:
         assert error.field is None
         assert error.value is None
 
-    def test_create_validation_error_with_field(self):
+    def test_create_validation_error_with_field(self) -> None:
         """Test creating validation error with field."""
         error = ValidationError("Field is required", field="title")
 
@@ -179,7 +179,7 @@ class TestValidationError:
         assert "Field is required" in str(error)
         assert "(field: title)" in str(error)
 
-    def test_create_validation_error_with_field_and_value(self):
+    def test_create_validation_error_with_field_and_value(self) -> None:
         """Test creating validation error with field and value."""
         error = ValidationError("Invalid priority", field="priority", value="invalid")
 
@@ -189,7 +189,7 @@ class TestValidationError:
         assert "(field: priority)" in str(error)
         assert "(value: invalid)" in str(error)
 
-    def test_validation_error_with_none_value(self):
+    def test_validation_error_with_none_value(self) -> None:
         """Test validation error where value is explicitly None."""
         error = ValidationError("Required field", field="description", value=None)
 
@@ -200,7 +200,7 @@ class TestValidationError:
         # Should not include value when it's None
         assert "(value: None)" not in error_str
 
-    def test_validation_error_inheritance(self):
+    def test_validation_error_inheritance(self) -> None:
         """Test that ValidationError inherits from MCPTicketerError."""
         error = ValidationError("Validation failed", field="test")
 
@@ -208,7 +208,7 @@ class TestValidationError:
         assert isinstance(error, MCPTicketerError)
         assert isinstance(error, Exception)
 
-    def test_raise_validation_error(self):
+    def test_raise_validation_error(self) -> None:
         """Test raising validation error."""
         with pytest.raises(ValidationError) as exc_info:
             raise ValidationError("Invalid", field="state", value="bad_state")
@@ -221,20 +221,20 @@ class TestValidationError:
 class TestConfigurationError:
     """Test ConfigurationError exception."""
 
-    def test_create_configuration_error(self):
+    def test_create_configuration_error(self) -> None:
         """Test creating configuration error."""
         error = ConfigurationError("Missing API key")
 
         assert str(error) == "Missing API key"
 
-    def test_configuration_error_inheritance(self):
+    def test_configuration_error_inheritance(self) -> None:
         """Test that ConfigurationError inherits from MCPTicketerError."""
         error = ConfigurationError("Config error")
 
         assert isinstance(error, ConfigurationError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_configuration_error(self):
+    def test_raise_configuration_error(self) -> None:
         """Test raising configuration error."""
         with pytest.raises(ConfigurationError) as exc_info:
             raise ConfigurationError("Invalid config")
@@ -246,20 +246,20 @@ class TestConfigurationError:
 class TestCacheError:
     """Test CacheError exception."""
 
-    def test_create_cache_error(self):
+    def test_create_cache_error(self) -> None:
         """Test creating cache error."""
         error = CacheError("Cache write failed")
 
         assert str(error) == "Cache write failed"
 
-    def test_cache_error_inheritance(self):
+    def test_cache_error_inheritance(self) -> None:
         """Test that CacheError inherits from MCPTicketerError."""
         error = CacheError("Cache error")
 
         assert isinstance(error, CacheError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_cache_error(self):
+    def test_raise_cache_error(self) -> None:
         """Test raising cache error."""
         with pytest.raises(CacheError) as exc_info:
             raise CacheError("Cache corrupted")
@@ -271,7 +271,7 @@ class TestCacheError:
 class TestStateTransitionError:
     """Test StateTransitionError exception."""
 
-    def test_create_state_transition_error(self):
+    def test_create_state_transition_error(self) -> None:
         """Test creating state transition error."""
         error = StateTransitionError(
             "Invalid transition", from_state=TicketState.OPEN, to_state=TicketState.DONE
@@ -284,7 +284,7 @@ class TestStateTransitionError:
         assert "DONE" in str(error)
         assert "->" in str(error)
 
-    def test_state_transition_error_string_representation(self):
+    def test_state_transition_error_string_representation(self) -> None:
         """Test state transition error string representation."""
         error = StateTransitionError(
             "Cannot transition",
@@ -298,7 +298,7 @@ class TestStateTransitionError:
         assert "IN_PROGRESS" in error_str
         assert "->" in error_str
 
-    def test_state_transition_error_inheritance(self):
+    def test_state_transition_error_inheritance(self) -> None:
         """Test that StateTransitionError inherits from MCPTicketerError."""
         error = StateTransitionError(
             "Transition error", from_state=TicketState.OPEN, to_state=TicketState.CLOSED
@@ -307,7 +307,7 @@ class TestStateTransitionError:
         assert isinstance(error, StateTransitionError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_state_transition_error(self):
+    def test_raise_state_transition_error(self) -> None:
         """Test raising state transition error."""
         with pytest.raises(StateTransitionError) as exc_info:
             raise StateTransitionError(
@@ -324,7 +324,7 @@ class TestStateTransitionError:
 class TestNetworkError:
     """Test NetworkError exception."""
 
-    def test_create_network_error(self):
+    def test_create_network_error(self) -> None:
         """Test creating network error."""
         error = NetworkError("Connection timeout", "github")
 
@@ -332,7 +332,7 @@ class TestNetworkError:
         assert "[github]" in str(error)
         assert "Connection timeout" in str(error)
 
-    def test_network_error_inheritance(self):
+    def test_network_error_inheritance(self) -> None:
         """Test that NetworkError inherits from AdapterError."""
         error = NetworkError("Network error", "linear")
 
@@ -340,7 +340,7 @@ class TestNetworkError:
         assert isinstance(error, AdapterError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_network_error(self):
+    def test_raise_network_error(self) -> None:
         """Test raising network error."""
         with pytest.raises(NetworkError) as exc_info:
             raise NetworkError("DNS failed", "jira")
@@ -352,7 +352,7 @@ class TestNetworkError:
 class TestTimeoutError:
     """Test TimeoutError exception."""
 
-    def test_create_timeout_error(self):
+    def test_create_timeout_error(self) -> None:
         """Test creating timeout error."""
         error = TimeoutError("Request timed out", "linear")
 
@@ -360,7 +360,7 @@ class TestTimeoutError:
         assert "[linear]" in str(error)
         assert "Request timed out" in str(error)
 
-    def test_timeout_error_inheritance(self):
+    def test_timeout_error_inheritance(self) -> None:
         """Test that TimeoutError inherits from AdapterError."""
         error = TimeoutError("Timeout", "github")
 
@@ -368,7 +368,7 @@ class TestTimeoutError:
         assert isinstance(error, AdapterError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_timeout_error(self):
+    def test_raise_timeout_error(self) -> None:
         """Test raising timeout error."""
         with pytest.raises(TimeoutError) as exc_info:
             raise TimeoutError("Too slow", "test")
@@ -380,7 +380,7 @@ class TestTimeoutError:
 class TestNotFoundError:
     """Test NotFoundError exception."""
 
-    def test_create_not_found_error(self):
+    def test_create_not_found_error(self) -> None:
         """Test creating not found error."""
         error = NotFoundError("Ticket not found", "jira")
 
@@ -388,7 +388,7 @@ class TestNotFoundError:
         assert "[jira]" in str(error)
         assert "Ticket not found" in str(error)
 
-    def test_not_found_error_inheritance(self):
+    def test_not_found_error_inheritance(self) -> None:
         """Test that NotFoundError inherits from AdapterError."""
         error = NotFoundError("Not found", "linear")
 
@@ -396,7 +396,7 @@ class TestNotFoundError:
         assert isinstance(error, AdapterError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_not_found_error(self):
+    def test_raise_not_found_error(self) -> None:
         """Test raising not found error."""
         with pytest.raises(NotFoundError) as exc_info:
             raise NotFoundError("Missing resource", "github")
@@ -408,7 +408,7 @@ class TestNotFoundError:
 class TestPermissionError:
     """Test PermissionError exception."""
 
-    def test_create_permission_error(self):
+    def test_create_permission_error(self) -> None:
         """Test creating permission error."""
         error = PermissionError("Access denied", "linear")
 
@@ -416,7 +416,7 @@ class TestPermissionError:
         assert "[linear]" in str(error)
         assert "Access denied" in str(error)
 
-    def test_permission_error_inheritance(self):
+    def test_permission_error_inheritance(self) -> None:
         """Test that PermissionError inherits from AdapterError."""
         error = PermissionError("Forbidden", "jira")
 
@@ -424,7 +424,7 @@ class TestPermissionError:
         assert isinstance(error, AdapterError)
         assert isinstance(error, MCPTicketerError)
 
-    def test_raise_permission_error(self):
+    def test_raise_permission_error(self) -> None:
         """Test raising permission error."""
         with pytest.raises(PermissionError) as exc_info:
             raise PermissionError("No access", "github")
@@ -436,7 +436,7 @@ class TestPermissionError:
 class TestExceptionHierarchy:
     """Test exception inheritance hierarchy."""
 
-    def test_all_adapter_errors_inherit_from_adapter_error(self):
+    def test_all_adapter_errors_inherit_from_adapter_error(self) -> None:
         """Test that all adapter-specific errors inherit from AdapterError."""
         adapter_errors = [
             AuthenticationError("test", "test"),
@@ -451,7 +451,7 @@ class TestExceptionHierarchy:
             assert isinstance(error, AdapterError)
             assert isinstance(error, MCPTicketerError)
 
-    def test_all_errors_inherit_from_base(self):
+    def test_all_errors_inherit_from_base(self) -> None:
         """Test that all errors ultimately inherit from MCPTicketerError."""
         all_errors = [
             MCPTicketerError("test"),
@@ -472,7 +472,7 @@ class TestExceptionHierarchy:
             assert isinstance(error, MCPTicketerError)
             assert isinstance(error, Exception)
 
-    def test_catch_specific_errors(self):
+    def test_catch_specific_errors(self) -> None:
         """Test that specific errors can be caught specifically."""
         with pytest.raises(AuthenticationError):
             raise AuthenticationError("Auth failed", "test")
@@ -483,7 +483,7 @@ class TestExceptionHierarchy:
         with pytest.raises(ValidationError):
             raise ValidationError("Validation failed")
 
-    def test_catch_all_with_base_exception(self):
+    def test_catch_all_with_base_exception(self) -> None:
         """Test that all errors can be caught with MCPTicketerError."""
         errors_to_test = [
             AuthenticationError("test", "test"),
