@@ -20,14 +20,14 @@ from mcp_ticketer.core.models import (
 class TestPriority:
     """Test Priority enum."""
 
-    def test_priority_values(self):
+    def test_priority_values(self) -> None:
         """Test priority enum values."""
         assert Priority.LOW.value == "low"
         assert Priority.MEDIUM.value == "medium"
         assert Priority.HIGH.value == "high"
         assert Priority.CRITICAL.value == "critical"
 
-    def test_priority_comparison(self):
+    def test_priority_comparison(self) -> None:
         """Test priority enum comparison."""
         assert Priority.LOW == Priority.LOW
         assert Priority.HIGH != Priority.LOW
@@ -38,14 +38,14 @@ class TestPriority:
 class TestTicketType:
     """Test TicketType enum."""
 
-    def test_ticket_type_values(self):
+    def test_ticket_type_values(self) -> None:
         """Test ticket type enum values."""
         assert TicketType.EPIC.value == "epic"
         assert TicketType.ISSUE.value == "issue"
         assert TicketType.TASK.value == "task"
         assert TicketType.SUBTASK.value == "subtask"
 
-    def test_ticket_type_equality(self):
+    def test_ticket_type_equality(self) -> None:
         """Test ticket type equality."""
         assert TicketType.TASK == TicketType.TASK
         assert TicketType.TASK != TicketType.EPIC
@@ -58,7 +58,7 @@ class TestTicketType:
 class TestTicketState:
     """Test TicketState enum and state machine transitions."""
 
-    def test_state_values(self):
+    def test_state_values(self) -> None:
         """Test all state enum values."""
         assert TicketState.OPEN.value == "open"
         assert TicketState.IN_PROGRESS.value == "in_progress"
@@ -69,7 +69,7 @@ class TestTicketState:
         assert TicketState.BLOCKED.value == "blocked"
         assert TicketState.CLOSED.value == "closed"
 
-    def test_valid_transitions_from_open(self):
+    def test_valid_transitions_from_open(self) -> None:
         """Test valid state transitions from OPEN."""
         state = TicketState.OPEN
         assert state.can_transition_to(TicketState.IN_PROGRESS)
@@ -77,7 +77,7 @@ class TestTicketState:
         assert state.can_transition_to(TicketState.BLOCKED)
         assert state.can_transition_to(TicketState.CLOSED)
 
-    def test_invalid_transitions_from_open(self):
+    def test_invalid_transitions_from_open(self) -> None:
         """Test invalid state transitions from OPEN."""
         state = TicketState.OPEN
         assert not state.can_transition_to(TicketState.READY)
@@ -85,7 +85,7 @@ class TestTicketState:
         assert not state.can_transition_to(TicketState.DONE)
         assert not state.can_transition_to(TicketState.OPEN)
 
-    def test_valid_transitions_from_in_progress(self):
+    def test_valid_transitions_from_in_progress(self) -> None:
         """Test valid state transitions from IN_PROGRESS."""
         state = TicketState.IN_PROGRESS
         assert state.can_transition_to(TicketState.READY)
@@ -93,32 +93,32 @@ class TestTicketState:
         assert state.can_transition_to(TicketState.BLOCKED)
         assert state.can_transition_to(TicketState.OPEN)
 
-    def test_invalid_transitions_from_in_progress(self):
+    def test_invalid_transitions_from_in_progress(self) -> None:
         """Test invalid state transitions from IN_PROGRESS."""
         state = TicketState.IN_PROGRESS
         assert not state.can_transition_to(TicketState.TESTED)
         assert not state.can_transition_to(TicketState.DONE)
         assert not state.can_transition_to(TicketState.CLOSED)
 
-    def test_valid_transitions_from_ready(self):
+    def test_valid_transitions_from_ready(self) -> None:
         """Test valid state transitions from READY."""
         state = TicketState.READY
         assert state.can_transition_to(TicketState.TESTED)
         assert state.can_transition_to(TicketState.IN_PROGRESS)
         assert state.can_transition_to(TicketState.BLOCKED)
 
-    def test_valid_transitions_from_tested(self):
+    def test_valid_transitions_from_tested(self) -> None:
         """Test valid state transitions from TESTED."""
         state = TicketState.TESTED
         assert state.can_transition_to(TicketState.DONE)
         assert state.can_transition_to(TicketState.IN_PROGRESS)
 
-    def test_valid_transitions_from_done(self):
+    def test_valid_transitions_from_done(self) -> None:
         """Test valid state transitions from DONE."""
         state = TicketState.DONE
         assert state.can_transition_to(TicketState.CLOSED)
 
-    def test_closed_is_terminal_state(self):
+    def test_closed_is_terminal_state(self) -> None:
         """Test that CLOSED is a terminal state with no valid transitions."""
         state = TicketState.CLOSED
         assert not state.can_transition_to(TicketState.OPEN)
@@ -128,21 +128,21 @@ class TestTicketState:
         transitions = TicketState.valid_transitions()
         assert transitions[TicketState.CLOSED] == []
 
-    def test_valid_transitions_from_waiting(self):
+    def test_valid_transitions_from_waiting(self) -> None:
         """Test valid state transitions from WAITING."""
         state = TicketState.WAITING
         assert state.can_transition_to(TicketState.OPEN)
         assert state.can_transition_to(TicketState.IN_PROGRESS)
         assert state.can_transition_to(TicketState.CLOSED)
 
-    def test_valid_transitions_from_blocked(self):
+    def test_valid_transitions_from_blocked(self) -> None:
         """Test valid state transitions from BLOCKED."""
         state = TicketState.BLOCKED
         assert state.can_transition_to(TicketState.OPEN)
         assert state.can_transition_to(TicketState.IN_PROGRESS)
         assert state.can_transition_to(TicketState.CLOSED)
 
-    def test_valid_transitions_method_returns_dict(self):
+    def test_valid_transitions_method_returns_dict(self) -> None:
         """Test that valid_transitions returns a dictionary."""
         transitions = TicketState.valid_transitions()
         assert isinstance(transitions, dict)
@@ -155,7 +155,7 @@ class TestTicketState:
 class TestTask:
     """Test Task model."""
 
-    def test_create_task_with_minimal_data(self):
+    def test_create_task_with_minimal_data(self) -> None:
         """Test creating a task with minimal required data."""
         task = Task(title="Test Task")
 
@@ -167,7 +167,7 @@ class TestTask:
         assert task.id is None
         assert task.description is None
 
-    def test_create_task_with_full_data(self):
+    def test_create_task_with_full_data(self) -> None:
         """Test creating a task with all fields."""
         now = datetime.now()
         task = Task(
@@ -200,34 +200,34 @@ class TestTask:
         assert task.actual_hours == 3.5
         assert task.metadata == {"source": "test"}
 
-    def test_create_task_with_empty_title_fails(self):
+    def test_create_task_with_empty_title_fails(self) -> None:
         """Test that creating a task with empty title raises validation error."""
         with pytest.raises(ValidationError) as exc_info:
             Task(title="")
 
         assert "title" in str(exc_info.value)
 
-    def test_task_is_issue(self):
+    def test_task_is_issue(self) -> None:
         """Test is_issue method."""
         task = Task(title="Test", ticket_type=TicketType.ISSUE)
         assert task.is_issue()
         assert not task.is_task()
         assert not task.is_epic()
 
-    def test_task_is_task(self):
+    def test_task_is_task(self) -> None:
         """Test is_task method."""
         task = Task(title="Test", ticket_type=TicketType.TASK)
         assert task.is_task()
         assert not task.is_issue()
         assert not task.is_epic()
 
-    def test_task_is_subtask(self):
+    def test_task_is_subtask(self) -> None:
         """Test that SUBTASK is treated as a task."""
         task = Task(title="Test", ticket_type=TicketType.SUBTASK)
         assert task.is_task()
         assert not task.is_issue()
 
-    def test_task_validate_hierarchy_task_without_parent(self):
+    def test_task_validate_hierarchy_task_without_parent(self) -> None:
         """Test that tasks without parent_issue fail validation."""
         task = Task(title="Test", ticket_type=TicketType.TASK)
 
@@ -236,7 +236,7 @@ class TestTask:
         assert len(errors) > 0
         assert any("parent_issue" in error for error in errors)
 
-    def test_task_validate_hierarchy_task_with_parent_issue(self):
+    def test_task_validate_hierarchy_task_with_parent_issue(self) -> None:
         """Test that tasks with parent_issue pass validation."""
         task = Task(title="Test", ticket_type=TicketType.TASK, parent_issue="ISSUE-123")
 
@@ -245,7 +245,7 @@ class TestTask:
         # Should not have the "must have parent_issue" error
         assert not any("must have a parent_issue" in error for error in errors)
 
-    def test_task_validate_hierarchy_issue_with_parent_issue(self):
+    def test_task_validate_hierarchy_issue_with_parent_issue(self) -> None:
         """Test that issues with parent_issue fail validation."""
         task = Task(
             title="Test", ticket_type=TicketType.ISSUE, parent_issue="ISSUE-123"
@@ -256,7 +256,7 @@ class TestTask:
         assert len(errors) > 0
         assert any("parent_epic" in error for error in errors)
 
-    def test_task_validate_hierarchy_task_with_parent_epic(self):
+    def test_task_validate_hierarchy_task_with_parent_epic(self) -> None:
         """Test that tasks with parent_epic fail validation."""
         task = Task(
             title="Test",
@@ -270,7 +270,7 @@ class TestTask:
         assert len(errors) > 0
         assert any("should only have parent_issue" in error for error in errors)
 
-    def test_task_model_dump(self):
+    def test_task_model_dump(self) -> None:
         """Test that task can be serialized to dict."""
         task = Task(title="Test", priority=Priority.HIGH, state=TicketState.OPEN)
 
@@ -281,7 +281,7 @@ class TestTask:
         assert data["priority"] == "high"
         assert data["state"] == "open"
 
-    def test_task_model_dump_json(self):
+    def test_task_model_dump_json(self) -> None:
         """Test that task can be serialized to JSON."""
         task = Task(title="Test")
 
@@ -295,7 +295,7 @@ class TestTask:
 class TestEpic:
     """Test Epic model."""
 
-    def test_create_epic_with_minimal_data(self):
+    def test_create_epic_with_minimal_data(self) -> None:
         """Test creating an epic with minimal required data."""
         epic = Epic(title="Test Epic")
 
@@ -305,7 +305,7 @@ class TestEpic:
         assert epic.priority == Priority.MEDIUM
         assert epic.child_issues == []
 
-    def test_create_epic_with_full_data(self):
+    def test_create_epic_with_full_data(self) -> None:
         """Test creating an epic with all fields."""
         epic = Epic(
             id="EPIC-1",
@@ -322,7 +322,7 @@ class TestEpic:
         assert epic.ticket_type == TicketType.EPIC
         assert epic.child_issues == ["ISSUE-1", "ISSUE-2", "ISSUE-3"]
 
-    def test_epic_ticket_type_is_frozen(self):
+    def test_epic_ticket_type_is_frozen(self) -> None:
         """Test that epic ticket_type defaults to EPIC and is frozen after creation."""
         epic = Epic(title="Test")
 
@@ -333,7 +333,7 @@ class TestEpic:
         with pytest.raises(ValidationError):
             epic.ticket_type = TicketType.ISSUE
 
-    def test_epic_validate_hierarchy(self):
+    def test_epic_validate_hierarchy(self) -> None:
         """Test epic hierarchy validation."""
         epic = Epic(title="Test Epic")
 
@@ -342,7 +342,7 @@ class TestEpic:
         # Epics have no hierarchy constraints
         assert errors == []
 
-    def test_epic_model_dump(self):
+    def test_epic_model_dump(self) -> None:
         """Test that epic can be serialized to dict."""
         epic = Epic(title="Test", child_issues=["ISSUE-1", "ISSUE-2"])
 
@@ -358,7 +358,7 @@ class TestEpic:
 class TestComment:
     """Test Comment model."""
 
-    def test_create_comment_with_minimal_data(self):
+    def test_create_comment_with_minimal_data(self) -> None:
         """Test creating a comment with minimal required data."""
         comment = Comment(ticket_id="TASK-123", content="This is a comment")
 
@@ -368,7 +368,7 @@ class TestComment:
         assert comment.author is None
         assert comment.created_at is None
 
-    def test_create_comment_with_full_data(self):
+    def test_create_comment_with_full_data(self) -> None:
         """Test creating a comment with all fields."""
         now = datetime.now()
         comment = Comment(
@@ -387,14 +387,14 @@ class TestComment:
         assert comment.created_at == now
         assert comment.metadata == {"source": "api"}
 
-    def test_create_comment_with_empty_content_fails(self):
+    def test_create_comment_with_empty_content_fails(self) -> None:
         """Test that creating a comment with empty content raises validation error."""
         with pytest.raises(ValidationError) as exc_info:
             Comment(ticket_id="TASK-123", content="")
 
         assert "content" in str(exc_info.value)
 
-    def test_comment_model_dump(self):
+    def test_comment_model_dump(self) -> None:
         """Test that comment can be serialized to dict."""
         comment = Comment(ticket_id="TASK-123", content="Test comment")
 
@@ -409,7 +409,7 @@ class TestComment:
 class TestSearchQuery:
     """Test SearchQuery model."""
 
-    def test_create_search_query_with_defaults(self):
+    def test_create_search_query_with_defaults(self) -> None:
         """Test creating a search query with default values."""
         query = SearchQuery()
 
@@ -421,7 +421,7 @@ class TestSearchQuery:
         assert query.limit == 10
         assert query.offset == 0
 
-    def test_create_search_query_with_all_filters(self):
+    def test_create_search_query_with_all_filters(self) -> None:
         """Test creating a search query with all filters."""
         query = SearchQuery(
             query="test search",
@@ -441,28 +441,28 @@ class TestSearchQuery:
         assert query.limit == 50
         assert query.offset == 10
 
-    def test_search_query_limit_validation_min(self):
+    def test_search_query_limit_validation_min(self) -> None:
         """Test that limit must be greater than 0."""
         with pytest.raises(ValidationError) as exc_info:
             SearchQuery(limit=0)
 
         assert "limit" in str(exc_info.value)
 
-    def test_search_query_limit_validation_max(self):
+    def test_search_query_limit_validation_max(self) -> None:
         """Test that limit cannot exceed 100."""
         with pytest.raises(ValidationError) as exc_info:
             SearchQuery(limit=101)
 
         assert "limit" in str(exc_info.value)
 
-    def test_search_query_offset_validation(self):
+    def test_search_query_offset_validation(self) -> None:
         """Test that offset must be non-negative."""
         with pytest.raises(ValidationError) as exc_info:
             SearchQuery(offset=-1)
 
         assert "offset" in str(exc_info.value)
 
-    def test_search_query_valid_limits(self):
+    def test_search_query_valid_limits(self) -> None:
         """Test that valid limit values work."""
         query1 = SearchQuery(limit=1)
         assert query1.limit == 1
@@ -473,7 +473,7 @@ class TestSearchQuery:
         query3 = SearchQuery(limit=50)
         assert query3.limit == 50
 
-    def test_search_query_model_dump(self):
+    def test_search_query_model_dump(self) -> None:
         """Test that search query can be serialized to dict."""
         query = SearchQuery(query="test", state=TicketState.OPEN, limit=20)
 
